@@ -26,6 +26,7 @@
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+
 package com.google.refine.extension.database.mariadb;
 
 import java.sql.Connection;
@@ -49,6 +50,7 @@ import com.google.refine.extension.database.model.DatabaseInfo;
 import com.google.refine.extension.database.model.DatabaseRow;
 
 public class MariaDBDatabaseService extends DatabaseService {
+
     private static final Logger logger = LoggerFactory.getLogger("MariaDBDatabaseService");
     public static final String DB_NAME = "mariadb";
     public static final String DB_DRIVER = "org.mariadb.jdbc.Driver";
@@ -61,7 +63,7 @@ public class MariaDBDatabaseService extends DatabaseService {
         if (instance == null) {
             SQLType.registerSQLDriver(DB_NAME, DB_DRIVER);
             instance = new MariaDBDatabaseService();
-            if(logger.isDebugEnabled()) {
+            if (logger.isDebugEnabled()) {
                 logger.debug("MariaDBDatabaseService Instance: {}", instance);
             }
         }
@@ -69,65 +71,65 @@ public class MariaDBDatabaseService extends DatabaseService {
     }
 
     @Override
-    public boolean testConnection(DatabaseConfiguration dbConfig) throws DatabaseServiceException{
+    public boolean testConnection(DatabaseConfiguration dbConfig) throws DatabaseServiceException {
         return MariaDBConnectionManager.getInstance().testConnection(dbConfig);
     }
 
     @Override
-    public DatabaseInfo connect(DatabaseConfiguration dbConfig) throws DatabaseServiceException{
+    public DatabaseInfo connect(DatabaseConfiguration dbConfig) throws DatabaseServiceException {
         return getMetadata(dbConfig);
     }
-   
+
     @Override
-    public DatabaseInfo executeQuery(DatabaseConfiguration dbConfig, String query) throws DatabaseServiceException{
+    public DatabaseInfo executeQuery(DatabaseConfiguration dbConfig, String query) throws DatabaseServiceException {
         Connection connection = MariaDBConnectionManager.getInstance().getConnection(dbConfig, false);
-        try(Statement statement = connection.createStatement();
-            ResultSet queryResult = statement.executeQuery(query)) {
-                ResultSetMetaData metadata = queryResult.getMetaData();
-                int columnCount = metadata.getColumnCount();
-                ArrayList<DatabaseColumn> columns = new ArrayList<DatabaseColumn>(columnCount);
+        try (Statement statement = connection.createStatement();
+                ResultSet queryResult = statement.executeQuery(query)) {
+            ResultSetMetaData metadata = queryResult.getMetaData();
+            int columnCount = metadata.getColumnCount();
+            ArrayList<DatabaseColumn> columns = new ArrayList<DatabaseColumn>(columnCount);
+            for (int i = 1; i <= columnCount; i++) {
+                DatabaseColumn dc = new DatabaseColumn(
+                        metadata.getColumnName(i),
+                        metadata.getColumnLabel(i),
+                        DatabaseUtils.getDbColumnType(metadata.getColumnType(i)),
+                        metadata.getColumnDisplaySize(i));
+                columns.add(dc);
+            }
+            int index = 0;
+            List<DatabaseRow> rows = new ArrayList<DatabaseRow>();
+            while (queryResult.next()) {
+                DatabaseRow row = new DatabaseRow();
+                row.setIndex(index);
+                List<String> values = new ArrayList<String>(columnCount);
                 for (int i = 1; i <= columnCount; i++) {
-                    DatabaseColumn dc = new DatabaseColumn(
-                            metadata.getColumnName(i), 
-                            metadata.getColumnLabel(i),
-                            DatabaseUtils.getDbColumnType(metadata.getColumnType(i)),
-                            metadata.getColumnDisplaySize(i));
-                    columns.add(dc);  
+                    values.add(queryResult.getString(i));
                 }
-                int index = 0; 
-                List<DatabaseRow> rows = new ArrayList<DatabaseRow>();
-                while (queryResult.next()) {
-                    DatabaseRow row = new DatabaseRow();
-                    row.setIndex(index);
-                    List<String> values = new ArrayList<String>(columnCount);
-                    for (int i = 1; i <= columnCount; i++) {
-                        values.add(queryResult.getString(i));
-                    }
-                    row.setValues(values);
-                    rows.add(row);
-                    index++;
-                }
-                DatabaseInfo dbInfo = new DatabaseInfo();
-                dbInfo.setColumns(columns);
-                dbInfo.setRows(rows);
-                return dbInfo;
+                row.setValues(values);
+                rows.add(row);
+                index++;
+            }
+            DatabaseInfo dbInfo = new DatabaseInfo();
+            dbInfo.setColumns(columns);
+            dbInfo.setRows(rows);
+            return dbInfo;
         } catch (SQLException e) {
             logger.error("SQLException::", e);
-            throw new DatabaseServiceException(true, e.getSQLState(), e.getErrorCode(), e.getMessage());
+            throw new DatabaseServiceException(e);
         } finally {
             MariaDBConnectionManager.getInstance().shutdown();
         }
     }
-    
+
     /**
      * @param connectionInfo
      * @return
      * @throws DatabaseServiceException
      */
-    private DatabaseInfo getMetadata(DatabaseConfiguration connectionInfo)  throws DatabaseServiceException {
+    private DatabaseInfo getMetadata(DatabaseConfiguration connectionInfo) throws DatabaseServiceException {
         try {
             Connection connection = MariaDBConnectionManager.getInstance().getConnection(connectionInfo, true);
-            if(connection != null) {
+            if (connection != null) {
                 java.sql.DatabaseMetaData metadata = connection.getMetaData();
                 int dbMajorVersion = metadata.getDatabaseMajorVersion();
                 int dbMinorVersion = metadata.getDatabaseMinorVersion();
@@ -142,17 +144,17 @@ public class MariaDBDatabaseService extends DatabaseService {
             }
         } catch (SQLException e) {
             logger.error("SQLException::", e);
-            throw new DatabaseServiceException(true, e.getSQLState(), e.getErrorCode(), e.getMessage());
-        } 
-       
+            throw new DatabaseServiceException(e);
+        }
+
         return null;
     }
 
     @Override
-    public ArrayList<DatabaseColumn> getColumns(DatabaseConfiguration dbConfig, String query) throws DatabaseServiceException{
+    public ArrayList<DatabaseColumn> getColumns(DatabaseConfiguration dbConfig, String query) throws DatabaseServiceException {
         Connection connection = MariaDBConnectionManager.getInstance().getConnection(dbConfig, true);
-        try(Statement statement = connection.createStatement();
-            ResultSet queryResult = statement.executeQuery(query)) {
+        try (Statement statement = connection.createStatement();
+                ResultSet queryResult = statement.executeQuery(query)) {
             ResultSetMetaData metadata = queryResult.getMetaData();
             int columnCount = metadata.getColumnCount();
             ArrayList<DatabaseColumn> columns = new ArrayList<DatabaseColumn>(columnCount);
@@ -164,7 +166,7 @@ public class MariaDBDatabaseService extends DatabaseService {
             return columns;
         } catch (SQLException e) {
             logger.error("SQLException::", e);
-            throw new DatabaseServiceException(true, e.getSQLState(), e.getErrorCode(), e.getMessage());
+            throw new DatabaseServiceException(e);
         }
     }
 
@@ -172,35 +174,35 @@ public class MariaDBDatabaseService extends DatabaseService {
     public List<DatabaseRow> getRows(DatabaseConfiguration dbConfig, String query)
             throws DatabaseServiceException {
         Connection connection = MariaDBConnectionManager.getInstance().getConnection(dbConfig, false);
-        try(Statement statement = connection.createStatement();
-            ResultSet queryResult = statement.executeQuery(query)) {
-                ResultSetMetaData metadata = queryResult.getMetaData();
-                int columnCount = metadata.getColumnCount();
-                int index = 0; 
-                List<DatabaseRow> rows = new ArrayList<DatabaseRow>();
-                while (queryResult.next()) {
-                    DatabaseRow row = new DatabaseRow();
-                    row.setIndex(index);
-                    List<String> values = new ArrayList<String>(columnCount);
-                    for (int i = 1; i <= columnCount; i++) {
-                        values.add(queryResult.getString(i));
-                    }
-                    row.setValues(values);
-                    rows.add(row);
-                    index++;
+        try (Statement statement = connection.createStatement();
+                ResultSet queryResult = statement.executeQuery(query)) {
+            ResultSetMetaData metadata = queryResult.getMetaData();
+            int columnCount = metadata.getColumnCount();
+            int index = 0;
+            List<DatabaseRow> rows = new ArrayList<DatabaseRow>();
+            while (queryResult.next()) {
+                DatabaseRow row = new DatabaseRow();
+                row.setIndex(index);
+                List<String> values = new ArrayList<String>(columnCount);
+                for (int i = 1; i <= columnCount; i++) {
+                    values.add(queryResult.getString(i));
                 }
-                return rows;
+                row.setValues(values);
+                rows.add(row);
+                index++;
+            }
+            return rows;
         } catch (SQLException e) {
             logger.error("SQLException::", e);
-            throw new DatabaseServiceException(true, e.getSQLState(), e.getErrorCode(), e.getMessage());
+            throw new DatabaseServiceException(e);
         }
     }
 
     @Override
     protected String getDatabaseUrl(DatabaseConfiguration dbConfig) {
-            int port = dbConfig.getDatabasePort();
-            return "jdbc:" + dbConfig.getDatabaseType() + "://" + dbConfig.getDatabaseHost()
-                    + ((port == 0) ? "" : (":" + port)) + "/" + dbConfig.getDatabaseName() + "?useSSL=" + dbConfig.isUseSSL();
+        int port = dbConfig.getDatabasePort();
+        return "jdbc:" + dbConfig.getDatabaseType() + "://" + dbConfig.getDatabaseHost()
+                + ((port == 0) ? "" : (":" + port)) + "/" + dbConfig.getDatabaseName() + "?useSSL=" + dbConfig.isUseSSL();
     }
 
     @Override
@@ -213,7 +215,7 @@ public class MariaDBDatabaseService extends DatabaseService {
     @Override
     public DatabaseInfo testQuery(DatabaseConfiguration dbConfig, String query)
             throws DatabaseServiceException {
-        Statement statement  = null;
+        Statement statement = null;
         ResultSet queryResult = null;
         try {
             Connection connection = MariaDBConnectionManager.getInstance().getConnection(dbConfig, true);
@@ -223,13 +225,13 @@ public class MariaDBDatabaseService extends DatabaseService {
             return dbInfo;
         } catch (SQLException e) {
             logger.error("SQLException::", e);
-            throw new DatabaseServiceException(true, e.getSQLState(), e.getErrorCode(), e.getMessage());
+            throw new DatabaseServiceException(e);
         } finally {
             try {
                 if (queryResult != null) {
                     queryResult.close();
                 }
-                if (statement != null) { 
+                if (statement != null) {
                     statement.close();
                 }
             } catch (SQLException e) {
