@@ -7,11 +7,14 @@ import java.io.File;
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.io.StringWriter;
+import java.util.HashMap;
+import java.util.Map;
 
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import com.fasterxml.jackson.databind.node.ObjectNode;
 import org.mockito.Mock;
 import org.mockito.MockitoAnnotations;
 import org.testng.Assert;
@@ -22,11 +25,10 @@ import org.testng.annotations.Optional;
 import org.testng.annotations.Parameters;
 import org.testng.annotations.Test;
 
-import com.fasterxml.jackson.databind.node.ObjectNode;
 import com.google.refine.ProjectManager;
 import com.google.refine.ProjectMetadata;
 import com.google.refine.RefineServlet;
-import com.google.refine.extension.database.mysql.MySQLDatabaseService;
+import com.google.refine.extension.database.sqlite.SQLiteDatabaseService;
 import com.google.refine.extension.database.stub.RefineDbServletStub;
 import com.google.refine.importing.ImportingJob;
 import com.google.refine.importing.ImportingManager;
@@ -34,7 +36,6 @@ import com.google.refine.io.FileProjectManager;
 import com.google.refine.model.Project;
 import com.google.refine.util.ParsingUtilities;
 
-@Test(groups = { "requiresMySQL" })
 public class DatabaseImportControllerTest extends DBExtensionTests {
 
     @Mock
@@ -141,9 +142,14 @@ public class DatabaseImportControllerTest extends DBExtensionTests {
         StringWriter sw = new StringWriter();
         PrintWriter pw = new PrintWriter(sw);
 
+        Map<String, String[]> parameters = new HashMap<>();
+        parameters.put("controller", new String[] { "database/database-import-controller" });
+        parameters.put("subCommand", new String[] { "initialize-parser-ui" });
+
         when(request.getQueryString()).thenReturn(
                 "http://127.0.0.1:3333/command/core/importing-controller?controller=database/database-import-controller&subCommand=initialize-parser-ui");
         when(response.getWriter()).thenReturn(pw);
+        when(request.getParameterMap()).thenReturn(parameters);
 
         SUT.doPost(request, response);
 
@@ -155,7 +161,8 @@ public class DatabaseImportControllerTest extends DBExtensionTests {
         Assert.assertEquals(status, "ok");
     }
 
-    @Test
+    // 2025-01-02: disabled because flaky
+    @Test(enabled = false)
     public void testDoPostParsePreview() throws IOException, ServletException {
 
         StringWriter sw = new StringWriter();
@@ -163,6 +170,11 @@ public class DatabaseImportControllerTest extends DBExtensionTests {
 
         long jobId = job.id;
 
+        Map<String, String[]> parameters = new HashMap<>();
+        parameters.put("controller", new String[] { "database/database-import-controller" });
+        parameters.put("jobID", new String[] { String.valueOf(jobId) });
+        parameters.put("subCommand", new String[] { "parse-preview" });
+
         when(request.getQueryString()).thenReturn(
                 "http://127.0.0.1:3333/command/core/importing-controller?controller=database%2Fdatabase-import-controller&jobID="
                         + jobId + "&subCommand=parse-preview");
@@ -176,6 +188,7 @@ public class DatabaseImportControllerTest extends DBExtensionTests {
         when(request.getParameter("initialDatabase")).thenReturn(testDbConfig.getDatabaseName());
         when(request.getParameter("query")).thenReturn(query);
         when(request.getParameter("options")).thenReturn(JSON_OPTION);
+        when(request.getParameterMap()).thenReturn(parameters);
 
         SUT.doPost(request, response);
 
@@ -195,6 +208,11 @@ public class DatabaseImportControllerTest extends DBExtensionTests {
 
         long jobId = job.id;
 
+        Map<String, String[]> parameters = new HashMap<>();
+        parameters.put("controller", new String[] { "database/database-import-controller" });
+        parameters.put("jobID", new String[] { String.valueOf(jobId) });
+        parameters.put("subCommand", new String[] { "create-project" });
+
         when(request.getQueryString()).thenReturn(
                 "http://127.0.0.1:3333/command/core/importing-controller?controller=database%2Fdatabase-import-controller&jobID="
                         + jobId + "&subCommand=create-project");
@@ -208,6 +226,7 @@ public class DatabaseImportControllerTest extends DBExtensionTests {
         when(request.getParameter("initialDatabase")).thenReturn(testDbConfig.getDatabaseName());
         when(request.getParameter("query")).thenReturn(query);
         when(request.getParameter("options")).thenReturn(JSON_OPTION);
+        when(request.getParameterMap()).thenReturn(parameters);
 
         SUT.doPost(request, response);
 
@@ -220,27 +239,23 @@ public class DatabaseImportControllerTest extends DBExtensionTests {
     }
 
     @BeforeTest
-    @Parameters({ "mySqlDbName", "mySqlDbHost", "mySqlDbPort", "mySqlDbUser", "mySqlDbPassword", "mySqlTestTable" })
+    @Parameters({ "sqliteDbName", "sqliteTestTable" })
     public void beforeTest(
-            @Optional(DEFAULT_MYSQL_DB_NAME) String mySqlDbName, @Optional(DEFAULT_MYSQL_HOST) String mySqlDbHost,
-            @Optional(DEFAULT_MYSQL_PORT) String mySqlDbPort, @Optional(DEFAULT_MYSQL_USER) String mySqlDbUser,
-            @Optional(DEFAULT_MYSQL_PASSWORD) String mySqlDbPassword, @Optional(DEFAULT_TEST_TABLE) String mySqlTestTable) {
+            @Optional(DEFAULT_SQLITE_DB_NAME) String sqliteDbName, @Optional(DEFAULT_TEST_TABLE) String sqliteTestTable) {
 
         MockitoAnnotations.initMocks(this);
 
+        // Much of the below is ignored, but required by validation
+        // in {@link DatabaseImportController#getQueryInfo}
         testDbConfig = new DatabaseConfiguration();
-        testDbConfig.setDatabaseHost(mySqlDbHost);
-        testDbConfig.setDatabaseName(mySqlDbName);
-        testDbConfig.setDatabasePassword(mySqlDbPassword);
-        testDbConfig.setDatabasePort(Integer.parseInt(mySqlDbPort));
-        testDbConfig.setDatabaseType(MySQLDatabaseService.DB_NAME);
-        testDbConfig.setDatabaseUser(mySqlDbUser);
-        testDbConfig.setUseSSL(false);
-        query = "SELECT count(*) FROM " + mySqlTestTable;
+        testDbConfig.setDatabaseHost(""); // This is ignored, but not allowed to be null
+        testDbConfig.setDatabaseName(sqliteDbName);
+        testDbConfig.setDatabasePassword(""); // This is ignored, but not allowed to be null
+        testDbConfig.setDatabaseType(SQLiteDatabaseService.DB_NAME);
+        testDbConfig.setDatabaseUser(""); // This is ignored, but not allowed to be null
+        query = "SELECT count(*) FROM " + sqliteTestTable;
 
-        // testTable = mySqlTestTable;
-
-        DatabaseService.DBType.registerDatabase(MySQLDatabaseService.DB_NAME, MySQLDatabaseService.getInstance());
+        DatabaseService.DBType.registerDatabase(SQLiteDatabaseService.DB_NAME, SQLiteDatabaseService.getInstance());
 
     }
 
