@@ -29,17 +29,20 @@
 
 package com.google.refine.extension.database.sqlite;
 
+import java.sql.Connection;
+import java.sql.SQLException;
+
+import org.mockito.MockitoAnnotations;
+import org.testng.Assert;
+import org.testng.annotations.BeforeTest;
+import org.testng.annotations.Optional;
+import org.testng.annotations.Parameters;
+import org.testng.annotations.Test;
+
 import com.google.refine.extension.database.DBExtensionTests;
 import com.google.refine.extension.database.DatabaseConfiguration;
 import com.google.refine.extension.database.DatabaseService;
 import com.google.refine.extension.database.DatabaseServiceException;
-import org.mockito.MockitoAnnotations;
-import org.testng.Assert;
-import org.testng.annotations.*;
-
-import java.io.File;
-import java.sql.Connection;
-import java.sql.SQLException;
 
 @Test(groups = { "requiresSQLite" })
 public class SQLiteConnectionManagerTest extends DBExtensionTests {
@@ -61,15 +64,6 @@ public class SQLiteConnectionManagerTest extends DBExtensionTests {
         DatabaseService.DBType.registerDatabase(SQLiteDatabaseService.DB_NAME, SQLiteDatabaseService.getInstance());
     }
 
-    @AfterTest
-    @Parameters({ "sqliteDbName" })
-    public void afterTest(@Optional(DEFAULT_SQLITE_DB_NAME) String sqliteDbName) {
-        File f = new File(sqliteDbName);
-        if (f.exists()) {
-            f.delete();
-        }
-    }
-
     @Test
     public void testTestConnection() throws DatabaseServiceException {
         boolean isConnected = SQLiteConnectionManager.getInstance().testConnection(testDbConfig);
