@@ -1,10 +1,13 @@
 
 package org.openrefine.wikibase.commands;
 
-import static com.google.refine.util.TestUtils.assertEqualAsJson;
+import static com.google.refine.util.TestUtils.assertEqualsAsJson;
 import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 import static org.openrefine.wikibase.commands.LoginCommand.ACCESS_SECRET;
 import static org.openrefine.wikibase.commands.LoginCommand.ACCESS_TOKEN;
 import static org.openrefine.wikibase.commands.LoginCommand.API_ENDPOINT;
@@ -16,9 +19,6 @@ import static org.openrefine.wikibase.commands.LoginCommand.WIKIBASE_COOKIE_PREF
 import static org.openrefine.wikibase.commands.LoginCommand.getCookieValue;
 import static org.openrefine.wikibase.commands.LoginCommand.removeCRLF;
 import static org.openrefine.wikibase.commands.LoginCommand.sanitizeCookieKey;
-import static org.mockito.Mockito.doNothing;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.when;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertFalse;
 import static org.testng.Assert.assertNotEquals;
@@ -97,13 +97,13 @@ public class LoginCommandTest extends CommandTest {
     public void testNoApiEndpointPost() throws ServletException, IOException {
         when(request.getParameter("csrf_token")).thenReturn(Command.csrfFactory.getFreshToken());
         command.doPost(request, response);
-        assertEqualAsJson("{\"code\":\"error\",\"message\":\"missing parameter 'wb-api-endpoint'\"}", writer.toString());
+        assertEqualsAsJson(writer.toString(), "{\"code\":\"error\",\"message\":\"missing parameter 'wb-api-endpoint'\"}");
     }
 
     @Test
     public void testNoApiEndpointGet() throws ServletException, IOException {
         command.doGet(request, response);
-        assertEqualAsJson("{\"code\":\"error\",\"message\":\"missing parameter 'wb-api-endpoint'\"}", writer.toString());
+        assertEqualsAsJson(writer.toString(), "{\"code\":\"error\",\"message\":\"missing parameter 'wb-api-endpoint'\"}");
     }
 
     @Test
@@ -111,25 +111,25 @@ public class LoginCommandTest extends CommandTest {
         when(request.getParameter("csrf_token")).thenReturn(Command.csrfFactory.getFreshToken());
         when(request.getParameter(API_ENDPOINT)).thenReturn(apiEndpoint);
         command.doPost(request, response);
-        assertEqualAsJson("{\"logged_in\":false,\"username\":null,\"mediawiki_api_endpoint\":\"" + apiEndpoint + "\"}", writer.toString());
+        assertEqualsAsJson(writer.toString(), "{\"logged_in\":false,\"username\":null,\"mediawiki_api_endpoint\":\"" + apiEndpoint + "\"}");
     }
 
     @Test
     public void testCsrfProtection() throws ServletException, IOException {
         command.doPost(request, response);
-        assertEqualAsJson("{\"code\":\"error\",\"message\":\"Missing or invalid csrf_token parameter\"}", writer.toString());
+        assertEqualsAsJson(writer.toString(), "{\"code\":\"error\",\"message\":\"Missing or invalid csrf_token parameter\"}");
     }
 
     @Test
     public void testGetNotCsrfProtected() throws ServletException, IOException {
         when(request.getParameter(API_ENDPOINT)).thenReturn(apiEndpoint);
         command.doGet(request, response);
-        assertEqualAsJson("{\"logged_in\":false,\"username\":null,\"mediawiki_api_endpoint\":\"" + apiEndpoint + "\"}", writer.toString());
+        assertEqualsAsJson(writer.toString(), "{\"logged_in\":false,\"username\":null,\"mediawiki_api_endpoint\":\"" + apiEndpoint + "\"}");
     }
 
     private void assertLogin() {
-        assertEqualAsJson("{\"logged_in\":true,\"username\":\"" + username + "\",\"mediawiki_api_endpoint\":\"" + apiEndpoint + "\"}",
-                writer.toString());
+        assertEqualsAsJson(writer.toString(),
+                "{\"logged_in\":true,\"username\":\"" + username + "\",\"mediawiki_api_endpoint\":\"" + apiEndpoint + "\"}");
     }
 
     @Test
@@ -234,6 +234,13 @@ public class LoginCommandTest extends CommandTest {
         when(connectionManager.getConnection(apiEndpoint)).thenReturn(connection);
         when(connection.getCurrentUser()).thenReturn(username);
 
+        // Make sure that we have a custom user agent set (not a very effective test, but the best we can do without
+        // refactoring
+        when(connection.getCustomUserAgent()).thenReturn("test-wdtk-lib");
+        connectionManager.setupConnection(connection);
+        verify(connection, times(1)).getCustomUserAgent();
+        verify(connection, times(1)).setCustomUserAgent(Mockito.matches("^OpenRefine-Wikibase-extension.* test-wdtk-lib$"));
+
         command.doPost(request, response);
 
         verify(connectionManager, times(1)).login(apiEndpoint, consumerToken, consumerSecret, accessToken, accessSecret);
@@ -267,6 +274,13 @@ public class LoginCommandTest extends CommandTest {
         when(connectionManager.getConnection(apiEndpoint)).thenReturn(connection);
         when(connection.getCurrentUser()).thenReturn(username);
 
+        // Make sure that we have a custom user agent set (not a very effective test, but the best we can do without
+        // refactoring
+        when(connection.getCustomUserAgent()).thenReturn("test-wdtk-lib");
+        connectionManager.setupConnection(connection);
+        verify(connection, times(1)).getCustomUserAgent();
+        verify(connection, times(1)).setCustomUserAgent(Mockito.matches("^OpenRefine-Wikibase-extension.* test-wdtk-lib$"));
+
         command.doPost(request, response);
 
         verify(connectionManager, times(1)).login(apiEndpoint, consumerToken, consumerSecret, accessToken, accessSecret);
@@ -301,6 +315,13 @@ public class LoginCommandTest extends CommandTest {
         when(connectionManager.getConnection(apiEndpoint)).thenReturn(connection);
         when(connection.getCurrentUser()).thenReturn(username);
 
+        // Make sure that we have a custom user agent set (not a very effective test, but the best we can do without
+        // refactoring
+        when(connection.getCustomUserAgent()).thenReturn("test-wdtk-lib");
+        connectionManager.setupConnection(connection);
+        verify(connection, times(1)).getCustomUserAgent();
+        verify(connection, times(1)).setCustomUserAgent(Mockito.matches("^OpenRefine-Wikibase-extension.* test-wdtk-lib$"));
+
         command.doPost(request, response);
 
         verify(connectionManager, times(1)).login(apiEndpoint, consumerToken, consumerSecret, accessToken, accessSecret);
@@ -400,8 +421,8 @@ public class LoginCommandTest extends CommandTest {
 
         verify(connectionManager).logout(apiEndpoint);
         when(connectionManager.isLoggedIn(apiEndpoint)).thenReturn(false);
-        assertEqualAsJson("{\"logged_in\":false,\"username\":null, \"mediawiki_api_endpoint\":\"" + apiEndpoint + "\"}",
-                logoutWriter.toString());
+        assertEqualsAsJson(logoutWriter.toString(),
+                "{\"logged_in\":false,\"username\":null, \"mediawiki_api_endpoint\":\"" + apiEndpoint + "\"}");
 
         Map<String, Cookie> cookies = getCookieMap(
                 cookieCaptor.getAllValues().subList(loginCookiesSize, cookieCaptor.getAllValues().size()));
