@@ -37,7 +37,6 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.InputStreamReader;
 import java.io.LineNumberReader;
 import java.io.Reader;
 import java.io.UnsupportedEncodingException;
@@ -49,20 +48,34 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import com.fasterxml.jackson.databind.node.ObjectNode;
 import com.google.common.base.CharMatcher;
+import com.univocity.parsers.common.AbstractParser;
+import com.univocity.parsers.common.TextParsingException;
+import com.univocity.parsers.common.record.Record;
+import com.univocity.parsers.csv.CsvFormat;
+import com.univocity.parsers.csv.CsvParser;
+import com.univocity.parsers.csv.CsvParserSettings;
+import com.univocity.parsers.csv.UnescapedQuoteHandling;
+import com.univocity.parsers.tsv.TsvParser;
+import com.univocity.parsers.tsv.TsvParserSettings;
 import org.apache.commons.text.StringEscapeUtils;
 
-import com.fasterxml.jackson.databind.node.ObjectNode;
 import com.google.refine.ProjectMetadata;
 import com.google.refine.importing.ImportingJob;
 import com.google.refine.importing.ImportingUtilities;
 import com.google.refine.model.Project;
 import com.google.refine.util.JSONUtilities;
 
-import au.com.bytecode.opencsv.CSVParser;
-
 public class SeparatorBasedImporter extends TabularImportingParserBase {
 
+    // Excel limits: 1M rows x 16K columns, 32K characters max per cell
+    public static final int MAX_COLUMNS = 16 * 1024; // default 512
+    // TODO: Perhaps use a lower default and make user configurable?
+    public static final int MAX_CHARACTERS_PER_CELL = 1024 * 1024; // default 4096
+    public static final int GUESSER_LINE_COUNT = 100;
+    char DEFAULT_QUOTE_CHAR = new CsvParserSettings().getFormat().getQuote();
+
     public SeparatorBasedImporter() {
         super(false);
     }
@@ -73,11 +86,12 @@ public class SeparatorBasedImporter extends TabularImportingParserBase {
         ObjectNode options = super.createParserUIInitializationData(job, fileRecords, format);
 
         String separator = guessSeparator(job, fileRecords);
-        JSONUtilities.safePut(options, "separator", separator != null ? separator : "\\t");
+        String nonNullSeparator = separator != null ? separator : "\\t";
+        JSONUtilities.safePut(options, "separator", nonNullSeparator);
 
         JSONUtilities.safePut(options, "guessCellValueTypes", false);
-        JSONUtilities.safePut(options, "processQuotes", true);
-        JSONUtilities.safePut(options, "quoteCharacter", String.valueOf(CSVParser.DEFAULT_QUOTE_CHARACTER));
+        JSONUtilities.safePut(options, "processQuotes", !nonNullSeparator.equals("\\t"));
+        JSONUtilities.safePut(options, "quoteCharacter", String.valueOf(DEFAULT_QUOTE_CHAR));
         JSONUtilities.safePut(options, "trimStrings", true);
 
         return options;
@@ -101,11 +115,14 @@ public class SeparatorBasedImporter extends TabularImportingParserBase {
         boolean processQuotes = JSONUtilities.getBoolean(options, "processQuotes", true);
         boolean strictQuotes = JSONUtilities.getBoolean(options, "strictQuotes", false);
 
+        // TODO: Perhaps ask user to declare explicitly if they want TSV or weird CSV with \t separator hybrid?
+        boolean tsv = "\t".equals(sep) && !processQuotes && !strictQuotes;
+
         List<Object> retrievedColumnNames = null;
         if (options.has("columnNames")) {
             String[] strings = JSONUtilities.getStringArray(options, "columnNames");
             if (strings.length > 0) {
-                retrievedColumnNames = new ArrayList<Object>();
+                retrievedColumnNames = new ArrayList<>();
                 for (String s : strings) {
                     s = CharMatcher.whitespace().trimFrom(s);
                     if (!s.isEmpty()) {
@@ -123,56 +140,68 @@ public class SeparatorBasedImporter extends TabularImportingParserBase {
 
         final List<Object> columnNames = retrievedColumnNames;
 
-        Character quote = CSVParser.DEFAULT_QUOTE_CHARACTER;
+        Character quote = DEFAULT_QUOTE_CHAR;
         String quoteCharacter = JSONUtilities.getString(options, "quoteCharacter", null);
         if (quoteCharacter != null && CharMatcher.whitespace().trimFrom(quoteCharacter).length() == 1) {
             quote = CharMatcher.whitespace().trimFrom(quoteCharacter).charAt(0);
         }
 
-        final CSVParser parser = new CSVParser(
-                sep,
-                quote,
-                (char) 0, // we don't want escape processing
-                strictQuotes,
-                CSVParser.DEFAULT_IGNORE_LEADING_WHITESPACE,
-                !processQuotes);
+        AbstractParser parser;
+        if (tsv) {
+            TsvParserSettings settings = new TsvParserSettings();
+            settings.setMaxCharsPerColumn(MAX_CHARACTERS_PER_CELL);
+            settings.setMaxColumns(MAX_COLUMNS);
+            settings.setLineSeparatorDetectionEnabled(true);
+            settings.setIgnoreLeadingWhitespaces(false);
+            settings.setIgnoreTrailingWhitespaces(false);
+            parser = new TsvParser(settings);
+        } else {
+            CsvParserSettings settings = new CsvParserSettings();
+            CsvFormat format = settings.getFormat();
+            format.setDelimiter(sep);
+            format.setQuote(quote);
+            settings.setMaxColumns(MAX_COLUMNS);
+            settings.setLineSeparatorDetectionEnabled(true);
+            settings.setIgnoreLeadingWhitespaces(false);
+            settings.setIgnoreTrailingWhitespaces(false);
+            if (strictQuotes) {
+                settings.setUnescapedQuoteHandling(UnescapedQuoteHandling.RAISE_ERROR);
+            }
+            settings.setKeepQuotes(!processQuotes);
+            settings.setMaxCharsPerColumn(MAX_CHARACTERS_PER_CELL);
+            settings.setMaxColumns(MAX_COLUMNS);
+            parser = new CsvParser(settings);
+        }
+        try (final LineNumberReader lnReader = new LineNumberReader(reader);) {
 
-        final LineNumberReader lnReader = new LineNumberReader(reader);
+            parser.beginParsing(lnReader);
 
-        TableDataReader dataReader = new TableDataReader() {
+            TableDataReader dataReader = new TableDataReader() {
 
-            boolean usedColumnNames = false;
+                boolean usedColumnNames = false;
 
-            @Override
-            public List<Object> getNextRowOfCells() throws IOException {
-                if (columnNames != null && !usedColumnNames) {
-                    usedColumnNames = true;
-                    return columnNames;
-                } else {
-                    String line = lnReader.readLine();
-                    if (line == null) {
-                        return null;
+                @Override
+                public List<Object> getNextRowOfCells() throws IOException {
+                    if (columnNames != null && !usedColumnNames) {
+                        usedColumnNames = true;
+                        return columnNames;
                     } else {
-                        return getCells(line, parser, lnReader);
+                        Record record = parser.parseNextRecord();
+                        if (record != null) {
+                            return Arrays.asList(record.getValues());
+                        } else {
+                            return null;
+                        }
                     }
                 }
-            }
-        };
+            };
 
-        TabularImportingParserBase.readTable(project, job, dataReader, limit, options, exceptions);
-    }
-
-    static protected ArrayList<Object> getCells(String line, CSVParser parser, LineNumberReader lnReader)
-            throws IOException {
-
-        ArrayList<Object> cells = new ArrayList<Object>();
-        String[] tokens = parser.parseLineMulti(line);
-        cells.addAll(Arrays.asList(tokens));
-        while (parser.isPending()) {
-            tokens = parser.parseLineMulti(lnReader.readLine());
-            cells.addAll(Arrays.asList(tokens));
+            TabularImportingParserBase.readTable(project, job, dataReader, limit, options, exceptions);
+        } catch (TextParsingException e) {
+            exceptions.add(e);
+        } catch (IOException e) {
+            exceptions.add(e);
         }
-        return cells;
     }
 
     static public String guessSeparator(ImportingJob job, List<ObjectNode> fileRecords) {
@@ -185,8 +214,24 @@ public class SeparatorBasedImporter extends TabularImportingParserBase {
                 File file = new File(job.getRawDataDir(), location);
                 // Quotes are turned on by default, so use that for guessing
                 Separator separator = guessSeparator(file, encoding, true);
-                if (separator != null) {
-                    return StringEscapeUtils.escapeJava(Character.toString(separator.separator));
+                CsvFormat format = guessFormat(file, encoding);
+                if (format != null) {
+                    if (separator != null) {
+                        if (format.getDelimiter() != separator.separator) {
+                            logger.warn("Delimiter guesses disagree - uniVocity: '{}' - internal: '{}'", format.getDelimiter(),
+                                    separator.separator);
+                        }
+                        // Even if they disagree, use our guess for backward compatibility
+                        return StringEscapeUtils.escapeJava(Character.toString(separator.separator));
+                    } else {
+                        // We got a guess from CsvParser, but not ours, so let's use that
+                        return StringEscapeUtils.escapeJava(format.getDelimiterString());
+                    }
+                } else {
+                    if (separator != null) {
+                        // Our guesser worked when CsvParser's didn't
+                        return StringEscapeUtils.escapeJava(Character.toString(separator.separator));
+                    }
                 }
             }
         }
@@ -204,27 +249,43 @@ public class SeparatorBasedImporter extends TabularImportingParserBase {
         double stddev;
     }
 
+    static public CsvFormat guessFormat(File file, String encoding) {
+        try (InputStream is = new FileInputStream(file);
+                Reader reader = ImportingUtilities.getInputStreamReader(is, encoding);
+                LineNumberReader lineNumberReader = new LineNumberReader(reader)) {
+            CsvParserSettings settings = new CsvParserSettings();
+            // We could provide a set of delimiters to consider below if we wanted to restrict this
+            settings.detectFormatAutomatically();
+            settings.setFormatDetectorRowSampleCount(GUESSER_LINE_COUNT); // default is 20, but let's match our guesser
+            CsvParser parser = new CsvParser(settings);
+            parser.beginParsing(lineNumberReader);
+            // Format guesser result is available as soon as beginParsing() completes
+            return parser.getDetectedFormat();
+        } catch (IOException e) {
+            e.printStackTrace();
+            return null;
+        }
+    }
+
     static public Separator guessSeparator(File file, String encoding) {
         return guessSeparator(file, encoding, false); // quotes off for backward compatibility
     }
 
-    // TODO: Move this to the CSV project?
     static public Separator guessSeparator(File file, String encoding, boolean handleQuotes) {
         try {
-            InputStream is = new FileInputStream(file);
-            Reader reader = encoding != null ? new InputStreamReader(is, encoding) : new InputStreamReader(is);
-            LineNumberReader lineNumberReader = new LineNumberReader(reader);
+            try (InputStream is = new FileInputStream(file);
+                    Reader reader = ImportingUtilities.getInputStreamReader(is, encoding);
+                    LineNumberReader lineNumberReader = new LineNumberReader(reader)) {
 
-            try {
-                List<Separator> separators = new ArrayList<SeparatorBasedImporter.Separator>();
-                Map<Character, Separator> separatorMap = new HashMap<Character, SeparatorBasedImporter.Separator>();
+                List<Separator> separators = new ArrayList<>();
+                Map<Character, Separator> separatorMap = new HashMap<>();
 
                 int totalChars = 0;
                 int lineCount = 0;
                 boolean inQuote = false;
                 String s;
                 while (totalChars < 64 * 1024 &&
-                        lineCount < 100 &&
+                        lineCount < GUESSER_LINE_COUNT &&
                         (s = lineNumberReader.readLine()) != null) {
 
                     totalChars += s.length() + 1; // count the new line character
@@ -272,14 +333,7 @@ public class SeparatorBasedImporter extends TabularImportingParserBase {
                                         / ((double) lineCount * (lineCount - 1)));
                     }
 
-                    Collections.sort(separators, new Comparator<Separator>() {
-
-                        @Override
-                        public int compare(Separator sep0, Separator sep1) {
-                            return Double.compare(sep0.stddev / sep0.averagePerLine,
-                                    sep1.stddev / sep1.averagePerLine);
-                        }
-                    });
+                    Collections.sort(separators, Comparator.comparingDouble(sep0 -> sep0.stddev / sep0.averagePerLine));
 
                     Separator separator = separators.get(0);
                     if (separator.stddev / separator.averagePerLine < 0.1) {
@@ -287,10 +341,6 @@ public class SeparatorBasedImporter extends TabularImportingParserBase {
                     }
 
                 }
-            } finally {
-                lineNumberReader.close();
-                reader.close();
-                is.close();
             }
         } catch (UnsupportedEncodingException e) {
             e.printStackTrace();
