@@ -38,6 +38,8 @@ import java.util.List;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import org.apache.commons.lang.Validate;
+
 import com.google.refine.expr.ExpressionUtils;
 import com.google.refine.history.HistoryEntry;
 import com.google.refine.model.AbstractOperation;
@@ -64,6 +66,13 @@ public class MultiValuedCellJoinOperation extends AbstractOperation {
         _separator = separator;
     }
 
+    @Override
+    public void validate() {
+        Validate.notNull(_columnName, "Missing column name");
+        Validate.notNull(_keyColumnName, "Missing key column name");
+        Validate.notNull(_separator, "Missing separator");
+    }
+
     @JsonProperty("columnName")
     public String getColumnName() {
         return _columnName;
