@@ -39,11 +39,13 @@ import java.util.Properties;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
+
 import com.google.refine.browsing.EngineConfig;
 import com.google.refine.browsing.RowVisitor;
 import com.google.refine.expr.Evaluable;
 import com.google.refine.expr.ExpressionUtils;
 import com.google.refine.expr.MetaParser;
+import com.google.refine.expr.ParsingException;
 import com.google.refine.expr.WrappedCell;
 import com.google.refine.model.Cell;
 import com.google.refine.model.Column;
@@ -100,6 +102,16 @@ public class TextTransformOperation extends EngineDependentMassCellOperation {
         _repeatCount = repeatCount;
     }
 
+    @Override
+    public void validate() {
+        super.validate();
+        try {
+            MetaParser.parse(_expression);
+        } catch (ParsingException e) {
+            throw new IllegalArgumentException(e);
+        }
+    }
+
     @Override
     protected String getBriefDescription(Project project) {
         return OperationDescription.cell_text_transform_brief(_columnName, _expression);
