@@ -38,6 +38,8 @@ import java.util.List;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import org.apache.commons.lang.Validate;
+
 import com.google.refine.history.HistoryEntry;
 import com.google.refine.model.AbstractOperation;
 import com.google.refine.model.Cell;
@@ -60,6 +62,11 @@ public class TransposeRowsIntoColumnsOperation extends AbstractOperation {
         _rowCount = rowCount;
     }
 
+    @Override
+    public void validate() {
+        Validate.notNull(_columnName, "Missing column name");
+    }
+
     @JsonProperty("rowCount")
     public int getRowCount() {
         return _rowCount;
