@@ -35,6 +35,8 @@ package com.google.refine.operations.column;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import org.apache.commons.lang.Validate;
+
 import com.google.refine.history.Change;
 import com.google.refine.history.HistoryEntry;
 import com.google.refine.model.AbstractOperation;
@@ -53,6 +55,11 @@ public class ColumnRemovalOperation extends AbstractOperation {
         _columnName = columnName;
     }
 
+    @Override
+    public void validate() {
+        Validate.notNull(_columnName, "Missing column name");
+    }
+
     @JsonProperty("columnName")
     public String getColumnName() {
         return _columnName;
