@@ -38,13 +38,13 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.regex.Pattern;
 
-import com.google.refine.operations.OperationDescription;
-import org.apache.commons.lang3.StringUtils;
-
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonInclude;
 import com.fasterxml.jackson.annotation.JsonInclude.Include;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import org.apache.commons.lang.Validate;
+import org.apache.commons.lang3.StringUtils;
+
 import com.google.refine.browsing.Engine;
 import com.google.refine.browsing.EngineConfig;
 import com.google.refine.browsing.FilteredRows;
@@ -58,6 +58,7 @@ import com.google.refine.model.Project;
 import com.google.refine.model.Row;
 import com.google.refine.model.changes.ColumnSplitChange;
 import com.google.refine.operations.EngineDependentOperation;
+import com.google.refine.operations.OperationDescription;
 
 public class ColumnSplitOperation extends EngineDependentOperation {
 
@@ -102,6 +103,15 @@ public class ColumnSplitOperation extends EngineDependentOperation {
         }
     }
 
+    @Override
+    public void validate() {
+        super.validate();
+        Validate.notNull(_columnName, "Missing column name");
+        if (!"separator".equals(_mode)) {
+            Validate.notNull(_fieldLengths, "Missing field lengths");
+        }
+    }
+
     public ColumnSplitOperation(
             EngineConfig engineConfig,
             String columnName,
