@@ -9,8 +9,8 @@ const fixture = [
     cy.loadAndVisitProject(fixture);
     cy.columnActionClick('c', ['View', 'Collapse all columns to left']);
 
-    cy.get('[title="a"]').should('to.contain', '');
-    cy.get('[title="b"]').should('to.contain', '');
+    cy.get('[title="Expand column \'a\'"]').should('to.contain', '');
+    cy.get('[title="Expand column \'b\'"]').should('to.contain', '');
 
   });
 });
