@@ -158,9 +158,11 @@ Cypress.Commands.add('cleanupProjects', () => {
           body: { project: projectId },
           form: true,
         }).then((resp) => {
-          cy.log('Deleted OR project' + projectId);
+          cy.log('Deleted OR project ' + projectId);
         });
       }
+      // clear loaded projects
+      loadedProjectIds.length = 0;
     });
   });
 });
@@ -171,6 +173,7 @@ Cypress.Commands.add('loadProject', (fixture, projectName, tagName) => {
 
   let jsonFixture;
   let content;
+  let escapedFields = [];
   const csv = [];
 
   if (fixture.includes('.csv')) {
@@ -183,8 +186,12 @@ Cypress.Commands.add('loadProject', (fixture, projectName, tagName) => {
     } else {
       jsonFixture = fixture;
     }
-    jsonFixture.forEach((item) => {
-      csv.push('"' + item.join('","') + '"');
+    jsonFixture.forEach((row) => {
+      escapedFields = [];
+      row.forEach((field) => {
+        escapedFields.push(field ? field.replaceAll('"','""') : field);
+      });
+      csv.push('"' + escapedFields.join('","') + '"');
     });
     content = csv.join('\n');
   }
@@ -197,7 +204,7 @@ Cypress.Commands.add('loadProject', (fixture, projectName, tagName) => {
     // It's conflicting though, breaking up the CSV files
     // It is a hack to parse out CSV files in the openrefine while creating a project with tags
     const options = {
-      encoding: 'US-ASCII',
+      encoding: 'UTF-8',
       separator: ',',
       ignoreLines: -1,
       headerLines: 1,
