@@ -40,10 +40,15 @@ import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import com.fasterxml.jackson.databind.node.ObjectNode;
+import edu.mit.simile.vicino.distances.LevenshteinDistance;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Test;
 
-import com.fasterxml.jackson.databind.node.ObjectNode;
+import com.google.refine.clustering.binning.KeyerFactory;
+import com.google.refine.clustering.binning.Metaphone3Keyer;
+import com.google.refine.clustering.knn.DistanceFactory;
+import com.google.refine.clustering.knn.VicinoDistance;
 import com.google.refine.commands.Command;
 import com.google.refine.util.JSONUtilities;
 import com.google.refine.util.ParsingUtilities;
@@ -56,16 +61,15 @@ public class GetClusteringFunctionsAndDistancesCommandTest {
     protected Command command = null;
 
     @BeforeMethod
-    public void setUp() {
+    public void setUp() throws IOException {
         request = mock(HttpServletRequest.class);
         response = mock(HttpServletResponse.class);
         command = new GetClusteringFunctionsAndDistancesCommand();
         writer = new StringWriter();
-        try {
-            when(response.getWriter()).thenReturn(new PrintWriter(writer));
-        } catch (IOException e) {
-            e.printStackTrace();
-        }
+        when(response.getWriter()).thenReturn(new PrintWriter(writer));
+
+        DistanceFactory.put("levenshtein", new VicinoDistance(new LevenshteinDistance()));
+        KeyerFactory.put("metaphone3", new Metaphone3Keyer());
     }
 
     @Test
