@@ -33,17 +33,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 package com.google.refine.exporters;
 
-import com.google.refine.ProjectManager;
-import com.google.refine.ProjectManagerStub;
-import com.google.refine.ProjectMetadata;
-import com.google.refine.RefineTest;
-import com.google.refine.browsing.Engine;
-import com.google.refine.browsing.Engine.Mode;
-import com.google.refine.model.Cell;
-import com.google.refine.model.Column;
-import com.google.refine.model.ModelException;
-import com.google.refine.model.Project;
-import com.google.refine.model.Row;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
+
+import java.io.IOException;
+import java.io.StringWriter;
+import java.util.Properties;
+
 import org.slf4j.LoggerFactory;
 import org.testng.Assert;
 import org.testng.annotations.AfterMethod;
@@ -51,12 +47,19 @@ import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.BeforeTest;
 import org.testng.annotations.Test;
 
-import java.io.IOException;
-import java.io.StringWriter;
-import java.util.Properties;
-
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.when;
+import com.google.refine.ProjectManager;
+import com.google.refine.ProjectManagerStub;
+import com.google.refine.ProjectMetadata;
+import com.google.refine.RefineTest;
+import com.google.refine.browsing.Engine;
+import com.google.refine.browsing.Engine.Mode;
+import com.google.refine.expr.MetaParser;
+import com.google.refine.grel.Parser;
+import com.google.refine.model.Cell;
+import com.google.refine.model.Column;
+import com.google.refine.model.ModelException;
+import com.google.refine.model.Project;
+import com.google.refine.model.Row;
 
 public class TemplatingExporterTests extends RefineTest {
 
@@ -68,6 +71,16 @@ public class TemplatingExporterTests extends RefineTest {
     String suffix = "<test suffix";
     String rowSeparator = "\n";
 
+    @BeforeMethod
+    public void registerGRELParser() {
+        MetaParser.registerLanguageParser("grel", "GREL", Parser.grelParser, "value");
+    }
+
+    @AfterMethod
+    public void unregisterGRELParser() {
+        MetaParser.unregisterLanguageParser("grel");
+    }
+
     @Override
     @BeforeTest
     public void init() {
@@ -108,7 +121,7 @@ public class TemplatingExporterTests extends RefineTest {
     }
 
     @Test
-    public void exportEmptyTemplate() {
+    public void exportEmptyTemplate() throws IOException {
 
 //        when(options.getProperty("limit")).thenReturn("100"); // optional integer
 //        when(options.getProperty("sorting")).thenReturn(""); //optional
@@ -118,17 +131,13 @@ public class TemplatingExporterTests extends RefineTest {
         when(options.getProperty("separator")).thenReturn(rowSeparator);
 //        when(options.getProperty("preview")).thenReturn("false"); // optional true|false
 
-        try {
-            SUT.export(project, options, engine, writer);
-        } catch (IOException e) {
-            Assert.fail();
-        }
+        SUT.export(project, options, engine, writer);
 
         Assert.assertEquals(writer.toString(), prefix + suffix);
     }
 
     @Test
-    public void exportSimpleTemplate() {
+    public void exportSimpleTemplate() throws IOException {
         CreateGrid(2, 2);
         String template = rowPrefix + "${column0}" + cellSeparator + "${column1}";
 //      String template = "boilerplate${column0}{{4+3}}${column1}";
@@ -141,11 +150,7 @@ public class TemplatingExporterTests extends RefineTest {
         when(options.getProperty("separator")).thenReturn(rowSeparator);
 //        when(options.getProperty("preview")).thenReturn("false"); // optional true|false
 
-        try {
-            SUT.export(project, options, engine, writer);
-        } catch (IOException e) {
-            Assert.fail();
-        }
+        SUT.export(project, options, engine, writer);
 
         Assert.assertEquals(writer.toString(),
                 prefix
@@ -155,7 +160,7 @@ public class TemplatingExporterTests extends RefineTest {
     }
 
     @Test()
-    public void exportTemplateWithEmptyCells() {
+    public void exportTemplateWithEmptyCells() throws IOException {
 
 //      when(options.getProperty("limit")).thenReturn("100"); // optional integer
 //      when(options.getProperty("sorting")).thenReturn(""); //optional
@@ -172,11 +177,7 @@ public class TemplatingExporterTests extends RefineTest {
 
         project.rows.get(1).cells.set(1, null);
         project.rows.get(2).cells.set(0, null);
-        try {
-            SUT.export(project, options, engine, writer);
-        } catch (IOException e) {
-            Assert.fail();
-        }
+        SUT.export(project, options, engine, writer);
 
         // Template exporter returns null for empty cells
         Assert.assertEquals(writer.toString(),
@@ -189,7 +190,7 @@ public class TemplatingExporterTests extends RefineTest {
     }
 
     @Test()
-    public void exportTemplateWithLimit() {
+    public void exportTemplateWithLimit() throws IOException {
 
         when(options.getProperty("limit")).thenReturn("2"); // optional integer
 //      when(options.getProperty("sorting")).thenReturn(""); //optional
@@ -202,11 +203,7 @@ public class TemplatingExporterTests extends RefineTest {
 
         CreateGrid(3, 3);
 
-        try {
-            SUT.export(project, options, engine, writer);
-        } catch (IOException e) {
-            Assert.fail();
-        }
+        SUT.export(project, options, engine, writer);
 
         Assert.assertEquals(writer.toString(),
                 prefix
@@ -222,7 +219,7 @@ public class TemplatingExporterTests extends RefineTest {
      * https://github.com/OpenRefine/OpenRefine/issues/3955
      */
     @Test
-    public void exportTemplateInRecordMode() {
+    public void exportTemplateInRecordMode() throws IOException {
         CreateColumns(2);
         for (int i = 0; i < 2; i++) {
             Row row = new Row(2);
@@ -243,11 +240,8 @@ public class TemplatingExporterTests extends RefineTest {
         Engine engine = new Engine(project);
         engine.setMode(Mode.RecordBased);
         project.update();
-        try {
-            SUT.export(project, options, engine, writer);
-        } catch (IOException e) {
-            Assert.fail();
-        }
+
+        SUT.export(project, options, engine, writer);
 
         Assert.assertEquals(writer.toString(),
                 prefix
@@ -261,18 +255,14 @@ public class TemplatingExporterTests extends RefineTest {
      * https://github.com/OpenRefine/OpenRefine/issues/3381
      */
     @Test
-    public void exportTemplateWithProperEscaping() {
+    public void exportTemplateWithProperEscaping() throws IOException {
         CreateGrid(2, 2);
         String template = rowPrefix + "{{\"\\}\\}\"}}" + cellSeparator + "{{\"\\}\\}\"}}";
         when(options.getProperty("template")).thenReturn(template);
         when(options.getProperty("prefix")).thenReturn(prefix);
         when(options.getProperty("suffix")).thenReturn(suffix);
         when(options.getProperty("separator")).thenReturn(rowSeparator);
-        try {
-            SUT.export(project, options, engine, writer);
-        } catch (IOException e) {
-            Assert.fail();
-        }
+        SUT.export(project, options, engine, writer);
 
         Assert.assertEquals(writer.toString(),
                 prefix
