@@ -36,25 +36,25 @@ package com.google.refine.importers;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.testng.Assert.assertEquals;
-import static org.testng.Assert.assertFalse;
-import static org.testng.Assert.assertNull;
-import static org.testng.Assert.assertTrue;
 
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.Serializable;
+import java.time.LocalDate;
 import java.time.OffsetDateTime;
+import java.time.ZoneId;
+import java.time.format.DateTimeFormatter;
 import java.util.List;
 
+import com.fasterxml.jackson.databind.node.ArrayNode;
 import org.slf4j.LoggerFactory;
-import org.testng.Assert;
 import org.testng.annotations.AfterMethod;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.BeforeTest;
 import org.testng.annotations.Test;
 
-import com.fasterxml.jackson.databind.node.ArrayNode;
-import com.google.refine.model.Row;
+import com.google.refine.model.Project;
 import com.google.refine.util.ParsingUtilities;
 
 public class OdsImporterTests extends ImporterTest {
@@ -86,6 +86,39 @@ public class OdsImporterTests extends ImporterTest {
         super.tearDown();
     }
 
+    @Test
+    public void readMultiSheetOds() throws Exception {
+
+        ArrayNode sheets = ParsingUtilities.mapper.createArrayNode();
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 3, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 1\", fileNameAndSheetIndex: \"file-source#1\", rows: 3, selected: true}"));
+        whenGetArrayOption("sheets", options, sheets);
+
+        whenGetIntegerOption("ignoreLines", options, 0);
+        whenGetIntegerOption("headerLines", options, 1);
+        whenGetIntegerOption("skipDataLines", options, 0);
+        whenGetIntegerOption("limit", options, -1);
+        whenGetBooleanOption("storeBlankCellsAsNulls", options, true);
+
+        InputStream stream = this.getClass().getClassLoader().getResourceAsStream("sample.ods");
+
+        parseOneFile(SUT, stream);
+
+        Project expectedProject = createProject(
+                new String[] { "a", "b" },
+                new Serializable[][] {
+                        { "c", "d" },
+                        { "e", "f" },
+                        { null, null },
+                        { 3.0, 4.0 },
+                        { 5.0, 6.0 },
+                        { null, null },
+                });
+        assertProjectEquals(project, expectedProject);
+    }
+
     @Test
     public void readOds() throws FileNotFoundException, IOException {
 
@@ -102,23 +135,25 @@ public class OdsImporterTests extends ImporterTest {
 
         InputStream stream = ClassLoader.getSystemResourceAsStream("films.ods");
 
-        try {
-            parseOneFile(SUT, stream);
-        } catch (Exception e) {
-            Assert.fail(e.getMessage());
-        }
+        parseOneFile(SUT, stream);
 
-        assertEquals(project.rows.size(), ROWS);
-        Row row = project.rows.get(0);
-        assertEquals(row.cells.size(), COLUMNS);
-        assertEquals((String) row.getCellValue(1), "2 Days In New York");
-        assertEquals(((OffsetDateTime) row.getCellValue(3)).toString().substring(0, 10), "2012-03-28");
-        assertEquals(((Number) row.getCellValue(5)).doubleValue(), 4.5, EPSILON);
+        // TODO dates should not be interpreted in a particular time zone like this
+        DateTimeFormatter format = DateTimeFormatter.ISO_LOCAL_DATE;
+        OffsetDateTime expectedDate = LocalDate.from(format.parse("2012-03-28"))
+                .atStartOfDay()
+                .atZone(ZoneId.systemDefault())
+                .toOffsetDateTime();
 
-        assertFalse((Boolean) row.getCellValue(7));
-        assertTrue((Boolean) project.rows.get(1).getCellValue(7));
-
-        assertNull((String) project.rows.get(2).getCellValue(2));
+        Project expectedProject = createProject(
+                new String[] { "Category", "Title", "Director", "Release Date", "Gross", "Rating", "Rank", "Good?" },
+                new Serializable[][] {
+                        { "Narrative Features", "2 Days In New York", "Julie Delpy", expectedDate, 1.0E7, 4.5, 1.0, false },
+                        { "Narrative Features", "Booster", null, null, null, null, null, true },
+                        { "Narrative Features", "Dark Horse", null, null, null, null, null, null },
+                        { "Narrative Features", "Fairhaven", null, null, null, null, null, null },
+                        { null, null, null, null, null, null, null, null }, // TODO: should likely not be there?
+                });
+        assertProjectEquals(project, expectedProject);
 
         verify(options, times(1)).get("ignoreLines");
         verify(options, times(1)).get("headerLines");
@@ -143,17 +178,13 @@ public class OdsImporterTests extends ImporterTest {
 
         InputStream stream = ClassLoader.getSystemResourceAsStream("NoData_NoSpreadsheet.ods");
 
-        try {
-            List<Exception> exceptions = parseOneFileAndReturnExceptions(SUT, stream);
-            assertEquals(exceptions.size(), 1);
-            Exception NPE = exceptions.get(0);
-            assertEquals(NPE.getMessage(),
-                    "Attempted to parse file as Ods file but failed. " +
-                            "No tables found in Ods file. " +
-                            "Please validate file format on https://odfvalidator.org/, then try re-uploading the file.");
-            assert NPE.getCause() instanceof java.lang.NullPointerException;
-        } catch (Exception e) {
-            Assert.fail(e.getMessage());
-        }
+        List<Exception> exceptions = parseOneFileAndReturnExceptions(SUT, stream);
+        assertEquals(exceptions.size(), 1);
+        Exception NPE = exceptions.get(0);
+        assertEquals(NPE.getMessage(),
+                "Attempted to parse file as Ods file but failed. " +
+                        "No tables found in Ods file. " +
+                        "Please validate file format on https://odfvalidator.org/, then try re-uploading the file.");
+        assert NPE.getCause() instanceof java.lang.NullPointerException;
     }
 }
