@@ -36,12 +36,9 @@ package com.google.refine.importers;
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.UnsupportedEncodingException;
-import java.util.ArrayList;
+import java.nio.charset.StandardCharsets;
 import java.util.List;
 
-import javax.xml.stream.XMLStreamException;
-
 import org.slf4j.LoggerFactory;
 import org.testng.Assert;
 import org.testng.annotations.AfterMethod;
@@ -57,11 +54,9 @@ import com.google.refine.importers.tree.ImportColumnGroup;
 import com.google.refine.importers.tree.ImportParameters;
 import com.google.refine.importers.tree.ImportRecord;
 import com.google.refine.importers.tree.TreeReader;
-import com.google.refine.importers.tree.TreeReaderException;
 import com.google.refine.model.Project;
 import com.google.refine.model.Row;
 
-
 public class XmlImportUtilitiesTests extends RefineTest {
 
     @Override
@@ -70,39 +65,40 @@ public class XmlImportUtilitiesTests extends RefineTest {
         logger = LoggerFactory.getLogger(this.getClass());
     }
 
-    //dependencies
+    // dependencies
     Project project;
     TreeReader parser;
     ImportColumnGroup columnGroup;
     ImportRecord record;
     ByteArrayInputStream inputStream;
 
-    //System Under Test
+    // System Under Test
     XmlImportUtilitiesStub SUT;
 
     @BeforeMethod
-    public void SetUp(){
+    public void SetUp() {
         SUT = new XmlImportUtilitiesStub();
         project = new Project();
         columnGroup = new ImportColumnGroup();
         record = new ImportRecord();
     }
 
+    @Override
     @AfterMethod
-    public void TearDown() throws IOException{
+    public void TearDown() throws IOException {
         SUT = null;
         project = null;
         parser = null;
         columnGroup = null;
         record = null;
-        if(inputStream != null) {
+        if (inputStream != null) {
             inputStream.close();
         }
         inputStream = null;
     }
 
     @Test
-    public void detectPathFromTagXmlTest() throws TreeReaderException{
+    public void detectPathFromTagXmlTest() throws Exception {
         loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author>author1</author><genre>genre1</genre></book></library>");
 
         String tag = "library";
@@ -115,7 +111,7 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void detectPathFromTagWithNestedElementXml() throws TreeReaderException{
+    public void detectPathFromTagWithNestedElementXml() throws Exception {
         loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author>author1</author><genre>genre1</genre></book></library>");
         String tag = "book";
 
@@ -129,36 +125,28 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void detectRecordElementXmlTest(){
+    public void detectRecordElementXmlTest() throws Exception {
         loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author>author1</author><genre>genre1</genre></book></library>");
         createXmlParser();
 
-        String tag="library";
+        String tag = "library";
+
+        List<String> response = SUT.detectRecordElementWrapper(parser, tag);
 
-        List<String> response = new ArrayList<String>();
-        try {
-            response = SUT.detectRecordElementWrapper(parser, tag);
-        } catch (Exception e) {
-            Assert.fail(e.getMessage());
-        }
         Assert.assertNotNull(response);
         Assert.assertEquals(response.size(), 1);
         Assert.assertEquals(response.get(0), "library");
     }
 
     @Test
-    public void detectRecordElementCanHandleWithNestedElementsXml(){
+    public void detectRecordElementCanHandleWithNestedElementsXml() throws Exception {
         loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author>author1</author><genre>genre1</genre></book></library>");
         createXmlParser();
 
-        String tag="book";
+        String tag = "book";
+
+        List<String> response = SUT.detectRecordElementWrapper(parser, tag);
 
-        List<String> response = new ArrayList<String>();
-        try {
-            response = SUT.detectRecordElementWrapper(parser, tag);
-        } catch (Exception e) {
-            Assert.fail(e.getMessage());
-        }
         Assert.assertNotNull(response);
         Assert.assertEquals(response.size(), 2);
         Assert.assertEquals(response.get(0), "library");
@@ -166,55 +154,25 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void detectRecordElementIsNullForUnfoundTagXml(){
+    public void detectRecordElementIsNullForUnfoundTagXml() throws Exception {
         loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author>author1</author><genre>genre1</genre></book></library>");
         createXmlParser();
 
-        String tag="";
+        String tag = "";
+
+        List<String> response = SUT.detectRecordElementWrapper(parser, tag);
 
-        List<String> response = new ArrayList<String>();
-        try {
-            response = SUT.detectRecordElementWrapper(parser, tag);
-        } catch (Exception e) {
-            Assert.fail(e.getMessage());
-        }
         Assert.assertNull(response);
     }
 
     @Test
-    public void detectRecordElementRegressionXmlTest(){
+    public void importTreeDataXmlTest() throws Exception {
         loadSampleXml();
 
-        String[] path = XmlImportUtilitiesStub.detectRecordElement(createXmlParser());
-        Assert.assertNotNull(path);
-        Assert.assertEquals(path.length, 2);
-        Assert.assertEquals(path[0], "library");
-        Assert.assertEquals(path[1], "book");
-    }
-    
-    @Test
-    public void detectRecordElementRegressionJsonTest(){
-        loadSampleJson();
+        String[] recordPath = new String[] { "library", "book" };
 
-        String[] path = XmlImportUtilitiesStub.detectRecordElement(
-                new JSONTreeReader(inputStream));
-        Assert.assertNotNull(path);
-        Assert.assertEquals(path.length, 2);
-        Assert.assertEquals(path[0], JsonImporter.ANONYMOUS);
-        Assert.assertEquals(path[1], JsonImporter.ANONYMOUS);
-    }
-
-    @Test
-    public void importTreeDataXmlTest(){
-        loadSampleXml();
-
-        String[] recordPath = new String[]{"library","book"};
-        try {
-            XmlImportUtilitiesStub.importTreeData(createXmlParser(), project, recordPath, columnGroup, -1,
-                    false, true, false);
-        } catch (Exception e){
-            Assert.fail();
-        }
+        XmlImportUtilitiesStub.importTreeData(createXmlParser(), project, recordPath, columnGroup, -1,
+                false, true, false);
 
         assertProjectCreated(project, 0, 6);
 
@@ -227,21 +185,17 @@ public class XmlImportUtilitiesTests extends RefineTest {
         Assert.assertNotNull(columnGroup.subgroups.get("book").subgroups.get("title"));
         Assert.assertNotNull(columnGroup.subgroups.get("book").subgroups.get("publish_date"));
     }
-    
+
     /**
      * Test of deprecated method which can go away when it does
      */
     @Test
-    public void importTreeDataXmlTestDeprecated(){
+    public void importTreeDataXmlTestDeprecated() throws Exception {
         loadSampleXml();
 
-        String[] recordPath = new String[]{"library","book"};
-        try {
-            XmlImportUtilitiesStub.importTreeData(createXmlParser(), project, recordPath, columnGroup, -1,
-                    new ImportParameters(false, true, false));
-        } catch (Exception e){
-            Assert.fail();
-        }
+        String[] recordPath = new String[] { "library", "book" };
+        XmlImportUtilitiesStub.importTreeData(createXmlParser(), project, recordPath, columnGroup, -1,
+                new ImportParameters(false, true, false));
 
         assertProjectCreated(project, 0, 6);
 
@@ -256,16 +210,12 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void importXmlWithVaryingStructureTest(){
+    public void importXmlWithVaryingStructureTest() throws Exception {
         loadData(XmlImporterTests.getSampleWithVaryingStructure());
 
-        String[] recordPath = new String[]{"library", "book"};
-        try {
-            XmlImportUtilitiesStub.importTreeData(createXmlParser(), project, recordPath, columnGroup, -1,
-                    false, true, false);
-        } catch (Exception e){
-            Assert.fail();
-        }
+        String[] recordPath = new String[] { "library", "book" };
+        XmlImportUtilitiesStub.importTreeData(createXmlParser(), project, recordPath, columnGroup, -1,
+                false, true, false);
 
         assertProjectCreated(project, 0, 6);
         Assert.assertEquals(project.rows.get(0).cells.size(), 4);
@@ -284,21 +234,16 @@ public class XmlImportUtilitiesTests extends RefineTest {
         Assert.assertNotNull(book.subgroups.get("genre"));
     }
 
-
     /**
      * Test using deprecated method which can go away when it does
      */
     @Test
-    public void importXmlWithVaryingStructureTestDeprecated(){
+    public void importXmlWithVaryingStructureTestDeprecated() throws Exception {
         loadData(XmlImporterTests.getSampleWithVaryingStructure());
 
-        String[] recordPath = new String[]{"library", "book"};
-        try {
-            XmlImportUtilitiesStub.importTreeData(createXmlParser(), project, recordPath, columnGroup, -1,
-                    new ImportParameters(false, true, false));
-        } catch (Exception e){
-            Assert.fail();
-        }
+        String[] recordPath = new String[] { "library", "book" };
+        XmlImportUtilitiesStub.importTreeData(createXmlParser(), project, recordPath, columnGroup, -1,
+                new ImportParameters(false, true, false));
 
         assertProjectCreated(project, 0, 6);
         Assert.assertEquals(project.rows.get(0).cells.size(), 4);
@@ -318,7 +263,7 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void createColumnsFromImportTest(){
+    public void createColumnsFromImportTest() {
 
         ImportColumnGroup columnGroup = new ImportColumnGroup();
         ImportColumnGroup subGroup = new ImportColumnGroup();
@@ -341,64 +286,52 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void findRecordTestXml(){
+    public void findRecordTestXml() throws Exception {
         loadSampleXml();
         createXmlParser();
         ParserSkip();
 
-        String[] recordPath = new String[]{"library","book"};
+        String[] recordPath = new String[] { "library", "book" };
         int pathIndex = 0;
 
-        try {
-            SUT.findRecordWrapper(project, parser, recordPath, pathIndex, columnGroup, -1,
-                    false, false, false);
-        } catch (Exception e) {
-            Assert.fail();
-        }
+        SUT.findRecordWrapper(project, parser, recordPath, pathIndex, columnGroup, -1,
+                false, false, false);
 
         assertProjectCreated(project, 0, 6);
 
         Assert.assertEquals(project.rows.get(0).cells.size(), 4);
-        //TODO
+        // TODO
     }
 
     /**
      * Test of deprecated wrapper method which can go away when it does
      */
     @Test
-    public void findRecordTestXmlDeprecated(){
+    public void findRecordTestXmlDeprecated() throws Exception {
         loadSampleXml();
         createXmlParser();
         ParserSkip();
 
-        String[] recordPath = new String[]{"library","book"};
+        String[] recordPath = new String[] { "library", "book" };
         int pathIndex = 0;
 
-        try {
-            SUT.findRecordWrapper(project, parser, recordPath, pathIndex, columnGroup, -1,
-                    new ImportParameters(false, false, false));
-        } catch (Exception e) {
-            Assert.fail();
-        }
+        SUT.findRecordWrapper(project, parser, recordPath, pathIndex, columnGroup, -1,
+                new ImportParameters(false, false, false));
 
         assertProjectCreated(project, 0, 6);
 
         Assert.assertEquals(project.rows.get(0).cells.size(), 4);
-        //TODO
+        // TODO
     }
 
-
     @Test
-    public void processRecordTestXml(){
+    public void processRecordTestXml() throws Exception {
         loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author>author1</author><genre>genre1</genre></book></library>");
         createXmlParser();
         ParserSkip();
 
-        try {
-            SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
-        } catch (Exception e) {
-            Assert.fail();
-        }
+        SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
+
         Assert.assertNotNull(project.rows);
         Assert.assertEquals(project.rows.size(), 1);
         Row row = project.rows.get(0);
@@ -409,16 +342,13 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void processRecordTestDuplicateColumnsXml(){
-        loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><authors><author>author1</author><author>author2</author></authors><genre>genre1</genre></book></library>");
+    public void processRecordTestDuplicateColumnsXml() throws Exception {
+        loadData(
+                "<?xml version=\"1.0\"?><library><book id=\"1\"><authors><author>author1</author><author>author2</author></authors><genre>genre1</genre></book></library>");
         createXmlParser();
         ParserSkip();
 
-        try {
-            SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
-        } catch (Exception e) {
-            Assert.fail();
-        }
+        SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
 
         Assert.assertNotNull(project.rows);
         Assert.assertEquals(project.rows.size(), 2);
@@ -434,16 +364,13 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void processRecordTestNestedElementXml(){
-        loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author><author-name>author1</author-name><author-dob>a date</author-dob></author><genre>genre1</genre></book></library>");
+    public void processRecordTestNestedElementXml() throws Exception {
+        loadData(
+                "<?xml version=\"1.0\"?><library><book id=\"1\"><author><author-name>author1</author-name><author-dob>a date</author-dob></author><genre>genre1</genre></book></library>");
         createXmlParser();
         ParserSkip();
 
-        try {
-            SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
-        } catch (Exception e) {
-            Assert.fail();
-        }
+        SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
 
         Assert.assertNotNull(project.rows);
         Assert.assertEquals(project.rows.size(), 1);
@@ -456,19 +383,14 @@ public class XmlImportUtilitiesTests extends RefineTest {
         Assert.assertEquals(row.getCell(2).value, "a date");
     }
 
-
     @Test
-    public void processSubRecordTestXml(){
+    public void processSubRecordTestXml() throws Exception {
         loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author>author1</author><genre>genre1</genre></book></library>");
         createXmlParser();
         ParserSkip();
 
-        try {
-            SUT.processSubRecordWrapper(project, parser, columnGroup, record,0, 
-                    new ImportParameters(false, false, false));
-        } catch (Exception e) {
-            Assert.fail();
-        }
+        SUT.processSubRecordWrapper(project, parser, columnGroup, record, 0,
+                new ImportParameters(false, false, false));
 
         Assert.assertEquals(columnGroup.subgroups.size(), 1);
         Assert.assertEquals(columnGroup.name, "");
@@ -482,20 +404,17 @@ public class XmlImportUtilitiesTests extends RefineTest {
         Assert.assertNotNull(book.subgroups.get("author"));
         Assert.assertNotNull(book.subgroups.get("genre"));
 
-        //TODO check record
+        // TODO check record
     }
 
     @Test
-    public void trimLeadingTrailingWhitespaceOnTrimString(){
-        loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author><author-name>  author1  </author-name><author-dob>  a date  </author-dob></author><genre>genre1</genre></book></library>");
+    public void trimLeadingTrailingWhitespaceOnTrimString() throws Exception {
+        loadData(
+                "<?xml version=\"1.0\"?><library><book id=\"1\"><author><author-name>  author1  </author-name><author-dob>  a date  </author-dob></author><genre>genre1</genre></book></library>");
         createXmlParser();
         ParserSkip();
 
-        try {
-            SUT.processRecordWrapper(project, parser, columnGroup, true, false, false);
-        } catch (Exception e) {
-            Assert.fail();
-        }
+        SUT.processRecordWrapper(project, parser, columnGroup, true, false, false);
 
         Assert.assertNotNull(project.rows);
         Assert.assertEquals(project.rows.size(), 1);
@@ -509,16 +428,13 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void doesNotTrimLeadingTrailingWhitespaceOnNoTrimString(){
-        loadData("<?xml version=\"1.0\"?><library><book id=\"1\"><author><author-name>  author1  </author-name><author-dob>  a date  </author-dob></author><genre>genre1</genre></book></library>");
+    public void doesNotTrimLeadingTrailingWhitespaceOnNoTrimString() throws Exception {
+        loadData(
+                "<?xml version=\"1.0\"?><library><book id=\"1\"><author><author-name>  author1  </author-name><author-dob>  a date  </author-dob></author><genre>genre1</genre></book></library>");
         createXmlParser();
         ParserSkip();
 
-        try {
-            SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
-        } catch (Exception e) {
-            Assert.fail();
-        }
+        SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
 
         Assert.assertNotNull(project.rows);
         Assert.assertEquals(project.rows.size(), 1);
@@ -532,7 +448,7 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void addCellTest(){
+    public void addCellTest() {
         String columnLocalName = "author";
         String text = "Author1, The";
         int commonStartingRowIndex = 0;
@@ -540,17 +456,17 @@ public class XmlImportUtilitiesTests extends RefineTest {
 
         Assert.assertNotNull(record);
         Assert.assertNotNull(record.rows);
-        //Assert.assertNotNull(record.columnEmptyRowIndices);
+        // Assert.assertNotNull(record.columnEmptyRowIndices);
         Assert.assertEquals(record.rows.size(), 1);
-        //Assert.assertEquals(record.columnEmptyRowIndices.size(), 2);
+        // Assert.assertEquals(record.columnEmptyRowIndices.size(), 2);
         Assert.assertNotNull(record.rows.get(0));
-        //Assert.assertNotNull(record.columnEmptyRowIndices.get(0));
-        //Assert.assertNotNull(record.columnEmptyRowIndices.get(1));
+        // Assert.assertNotNull(record.columnEmptyRowIndices.get(0));
+        // Assert.assertNotNull(record.columnEmptyRowIndices.get(1));
         Assert.assertEquals(record.rows.get(0).size(), 1);
         Assert.assertNotNull(record.rows.get(0).get(0));
         Assert.assertEquals(record.rows.get(0).get(0).value, "Author1, The");
-        //Assert.assertEquals(record.columnEmptyRowIndices.get(0).intValue(),0);
-        //Assert.assertEquals(record.columnEmptyRowIndices.get(1).intValue(),1);
+        // Assert.assertEquals(record.columnEmptyRowIndices.get(0).intValue(),0);
+        // Assert.assertEquals(record.columnEmptyRowIndices.get(1).intValue(),1);
 
     }
 
@@ -560,15 +476,12 @@ public class XmlImportUtilitiesTests extends RefineTest {
      * Fix: Issue#1095 :: Open XML file from URL generates lots of empty lines
      */
     @Test
-    public void processRecordsFromXmlWithWhiteSpacesBeforeTagsTest() throws IOException {
+    public void processRecordsFromXmlWithWhiteSpacesBeforeTagsTest() throws Exception {
         loadData(_getXmlDataFromFile("xml-sample-format-1.xml"));
         createXmlParser();
         ParserSkip();
-        try {
-            SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
-        } catch (Exception e) {
-            Assert.fail("Failed to parse records from the given XML Data. Reason: " + e.getMessage(), e);
-        }
+        SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
+
         Assert.assertNotNull(project.rows, "Checks the record count of project");
         Assert.assertEquals(project.rows.size(), 3, "Checks the number of records parsed from Xml");
         Row row = project.rows.get(0);
@@ -581,15 +494,13 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void processRecordsFromComplexXmlWithTagsHavingWhitespaces() throws IOException {
+    public void processRecordsFromComplexXmlWithTagsHavingWhitespaces() throws Exception {
         loadData(_getXmlDataFromFile("xml-sample-format-2.xml"));
         createXmlParser();
         ParserSkip();
-        try {
-            SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
-        } catch (Exception e) {
-            Assert.fail("Failed to parse records from the given XML Data. Reason: " + e.getMessage(), e);
-        }
+
+        SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
+
         Assert.assertNotNull(project.rows, "Checks the record count of project");
         Assert.assertEquals(project.rows.size(), 3, "Checks the number of records parsed from Xml");
         Row row = project.rows.get(0);
@@ -602,15 +513,13 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void processRecordsFromXMLWithDataHavingWhitespaces() throws IOException {
+    public void processRecordsFromXMLWithDataHavingWhitespaces() throws Exception {
         loadData(_getXmlDataFromFile("xml-sample-format-3.xml"));
         createXmlParser();
         ParserSkip();
-        try {
-            SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
-        } catch (Exception e) {
-            Assert.fail("Failed to parse records from the given XML Data. Reason: " + e.getMessage(), e);
-        }
+
+        SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
+
         Assert.assertNotNull(project.rows, "Checks the record count of project");
         Assert.assertEquals(project.rows.size(), 3, "Checks the number of records parsed from Xml");
         Row row = project.rows.get(0);
@@ -624,15 +533,13 @@ public class XmlImportUtilitiesTests extends RefineTest {
     }
 
     @Test
-    public void processRecordsFromComplexXmlStructure() throws IOException {
+    public void processRecordsFromComplexXmlStructure() throws Exception {
         loadData(_getXmlDataFromFile("xml-sample-format-4.xml"));
         createXmlParser();
         ParserSkip();
-        try {
-            SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
-        } catch (Exception e) {
-            Assert.fail("Failed to parse records from the given XML Data. Reason: " + e.getMessage(), e);
-        }
+
+        SUT.processRecordWrapper(project, parser, columnGroup, false, false, false);
+
         Assert.assertNotNull(project.rows, "Checks the record count of project");
         Assert.assertEquals(project.rows.size(), 50, "Checks the number of records parsed from Xml");
         Row row = project.rows.get(0);
@@ -644,44 +551,31 @@ public class XmlImportUtilitiesTests extends RefineTest {
         Assert.assertEquals(row.getCell(2).value, "50", "Checks the value for 'per-page'");
     }
 
-    //----------------helpers-------------
-    public void loadSampleXml(){
-        loadData( XmlImporterTests.getSample() );
-    }
-    
-    public void loadSampleJson(){
-        loadData( JsonImporterTests.getSample() );
+    // ----------------helpers-------------
+    public void loadSampleXml() {
+        loadData(XmlImporterTests.getSample());
     }
 
-    public void loadData(String xml){
-        try {
-            inputStream = new ByteArrayInputStream( xml.getBytes( "UTF-8" ) );
-        } catch (UnsupportedEncodingException e1) {
-            Assert.fail();
+    public void loadSampleJson() throws Exception {
+        loadData(JsonImporterTests.getSample());
+    }
+
+    public void loadData(String xml) {
+        inputStream = new ByteArrayInputStream(xml.getBytes(StandardCharsets.UTF_8));
+    }
+
+    public void ParserSkip() throws Exception {
+        if (parser.current() == TreeReader.Token.Ignorable) {
+            parser.next(); // move parser forward once e.g. skip the START_DOCUMENT parser event
         }
     }
 
-    public void ParserSkip(){
-        try {
-            if (parser.current() == TreeReader.Token.Ignorable){
-                parser.next(); //move parser forward once e.g. skip the START_DOCUMENT parser event
-            }
-        } catch (Exception e1) {
-            Assert.fail();
-        }
+    public TreeReader createXmlParser() throws Exception {
+        parser = new XmlParser(inputStream);
+        return parser;
     }
 
-    public TreeReader createXmlParser(){
-        try {
-            parser = new XmlParser(inputStream);
-            return parser;
-        } catch (XMLStreamException e) {
-            return null;
-        } catch (IOException e) {
-            return null;
-        }
-    }
-    public TreeReader createJsonParser(){
+    public TreeReader createJsonParser() {
         parser = new JSONTreeReader(inputStream);
         return parser;
     }
