@@ -27,9 +27,12 @@
 
 package com.google.refine.operations.column;
 
-import java.util.Arrays;
-import java.util.Properties;
+import static org.testng.Assert.assertThrows;
 
+import java.io.Serializable;
+import java.util.Arrays;
+
+import com.fasterxml.jackson.databind.node.TextNode;
 import org.testng.Assert;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.BeforeSuite;
@@ -38,8 +41,8 @@ import org.testng.annotations.Test;
 import com.google.refine.RefineTest;
 import com.google.refine.model.AbstractOperation;
 import com.google.refine.model.Project;
+import com.google.refine.operations.OperationDescription;
 import com.google.refine.operations.OperationRegistry;
-import com.google.refine.process.Process;
 import com.google.refine.util.TestUtils;
 
 public class ColumnReorderOperationTests extends RefineTest {
@@ -53,44 +56,66 @@ public class ColumnReorderOperationTests extends RefineTest {
 
     @BeforeMethod
     public void createProject() {
-        project = createCSVProject(
-                "a,b,c\n" +
-                        "1|2,d,e\n" +
-                        "3,f,g\n");
+        project = createProject(
+                new String[] { "a", "b", "c" },
+                new Serializable[][] {
+                        { "1|2", "d", "e" },
+                        { "3", "f", "g" },
+                });
     }
 
     @Test
     public void serializeColumnReorderOperation() {
         AbstractOperation op = new ColumnReorderOperation(Arrays.asList("b", "c", "a"));
         TestUtils.isSerializedTo(op, "{\"op\":\"core/column-reorder\","
-                + "\"description\":\"Reorder columns\","
+                + "\"description\":" + new TextNode(OperationDescription.column_reorder_brief()).toString() + ","
                 + "\"columnNames\":[\"b\",\"c\",\"a\"]}");
     }
 
+    @Test
+    public void testValidate() {
+        AbstractOperation op = new ColumnReorderOperation(null);
+        assertThrows(IllegalArgumentException.class, () -> op.validate());
+    }
+
     @Test
     public void testEraseCellsOnRemovedColumns() throws Exception {
 
-        int aCol = project.columnModel.getColumnByName("a").getCellIndex();
         int bCol = project.columnModel.getColumnByName("b").getCellIndex();
         int cCol = project.columnModel.getColumnByName("c").getCellIndex();
 
-        Assert.assertEquals(project.rows.get(0).getCellValue(aCol), "1|2");
-        Assert.assertEquals(project.rows.get(0).getCellValue(bCol), "d");
-        Assert.assertEquals(project.rows.get(0).getCellValue(cCol), "e");
-        Assert.assertEquals(project.rows.get(1).getCellValue(aCol), "3");
-        Assert.assertEquals(project.rows.get(1).getCellValue(bCol), "f");
-        Assert.assertEquals(project.rows.get(1).getCellValue(cCol), "g");
-
         AbstractOperation op = new ColumnReorderOperation(Arrays.asList("a"));
-        Process process = op.createProcess(project, new Properties());
-        process.performImmediate();
 
-        Assert.assertEquals(project.rows.get(0).getCellValue(aCol), "1|2");
+        runOperation(op, project);
+
+        Project expectedProject = createProject(
+                new String[] { "a" },
+                new Serializable[][] {
+                        { "1|2" },
+                        { "3" },
+                });
+        assertProjectEquals(project, expectedProject);
+
+        // deleted cell indices are nulled out
         Assert.assertEquals(project.rows.get(0).getCellValue(bCol), null);
         Assert.assertEquals(project.rows.get(0).getCellValue(cCol), null);
-        Assert.assertEquals(project.rows.get(1).getCellValue(aCol), "3");
         Assert.assertEquals(project.rows.get(1).getCellValue(bCol), null);
         Assert.assertEquals(project.rows.get(1).getCellValue(cCol), null);
 
     }
+
+    @Test
+    public void testReorder() throws Exception {
+        ColumnReorderOperation SUT = new ColumnReorderOperation(Arrays.asList("c", "b"));
+
+        runOperation(SUT, project);
+
+        Project expected = createProject(
+                new String[] { "c", "b" },
+                new Serializable[][] {
+                        { "e", "d" },
+                        { "g", "f" },
+                });
+        assertProjectEquals(project, expected);
+    }
 }
