@@ -36,9 +36,11 @@ package com.google.refine.operations.recon;
 import static org.mockito.Mockito.mock;
 
 import java.io.IOException;
+import java.io.Serializable;
 import java.io.StringWriter;
 import java.net.URLDecoder;
 import java.nio.charset.StandardCharsets;
+import java.time.OffsetDateTime;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
@@ -47,6 +49,12 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 
+import com.fasterxml.jackson.databind.JsonNode;
+import com.fasterxml.jackson.databind.node.TextNode;
+import okhttp3.mockwebserver.Dispatcher;
+import okhttp3.mockwebserver.MockResponse;
+import okhttp3.mockwebserver.MockWebServer;
+import okhttp3.mockwebserver.RecordedRequest;
 import org.slf4j.LoggerFactory;
 import org.testng.Assert;
 import org.testng.annotations.AfterMethod;
@@ -54,7 +62,6 @@ import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.BeforeTest;
 import org.testng.annotations.Test;
 
-import com.fasterxml.jackson.databind.JsonNode;
 import com.google.refine.RefineTest;
 import com.google.refine.browsing.Engine;
 import com.google.refine.browsing.EngineConfig;
@@ -64,20 +71,16 @@ import com.google.refine.model.Project;
 import com.google.refine.model.Recon;
 import com.google.refine.model.ReconCandidate;
 import com.google.refine.model.Row;
+import com.google.refine.model.recon.DataExtensionReconConfig;
 import com.google.refine.model.recon.ReconciledDataExtensionJob;
 import com.google.refine.model.recon.ReconciledDataExtensionJob.DataExtensionConfig;
 import com.google.refine.operations.EngineDependentOperation;
+import com.google.refine.operations.OperationDescription;
 import com.google.refine.operations.OperationRegistry;
-import com.google.refine.process.LongRunningProcessStub;
 import com.google.refine.process.Process;
 import com.google.refine.util.ParsingUtilities;
 import com.google.refine.util.TestUtils;
 
-import okhttp3.mockwebserver.Dispatcher;
-import okhttp3.mockwebserver.MockResponse;
-import okhttp3.mockwebserver.MockWebServer;
-import okhttp3.mockwebserver.RecordedRequest;
-
 public class ExtendDataOperationTests extends RefineTest {
 
     static final String ENGINE_JSON_URLS = "{\"mode\":\"row-based\"}}";
@@ -94,7 +97,7 @@ public class ExtendDataOperationTests extends RefineTest {
             + "}";
 
     private String operationJson = "{\"op\":\"core/extend-reconciled-data\","
-            + "\"description\":\"Extend data at index 3 based on column organization_name\","
+            + "\"description\":" + new TextNode(OperationDescription.recon_extend_data_brief(3, "organization_name")).toString() + ","
             + "\"engineConfig\":{\"mode\":\"row-based\",\"facets\":["
             + "    {\"selectNumeric\":true,\"expression\":\"cell.recon.best.score\",\"selectBlank\":false,\"selectNonNumeric\":true,\"selectError\":true,\"name\":\"organization_name: best candidate's score\",\"from\":13,\"to\":101,\"type\":\"range\",\"columnName\":\"organization_name\"},"
             + "    {\"selectNonTime\":true,\"expression\":\"grel:toDate(value)\",\"selectBlank\":true,\"selectError\":true,\"selectTime\":true,\"name\":\"start_year\",\"from\":410242968000,\"to\":1262309184000,\"type\":\"timerange\",\"columnName\":\"start_year\"}"
@@ -114,7 +117,8 @@ public class ExtendDataOperationTests extends RefineTest {
 
     private String processJson = ""
             + "    {\n" +
-            "       \"description\" : \"Extend data at index 3 based on column organization_name\",\n" +
+            "       \"description\" : " + new TextNode(OperationDescription.recon_extend_data_brief(3, "organization_name")).toString()
+            + ",\n" +
             "       \"id\" : %d,\n" +
             "       \"immediate\" : false,\n" +
             "       \"progress\" : 0,\n" +
@@ -144,6 +148,7 @@ public class ExtendDataOperationTests extends RefineTest {
 
     // dependencies
     Project project;
+    Cell reconCell1, reconCell2, reconCell3, reconCell4;
     Properties options;
     EngineConfig engine_config;
     Engine engine;
@@ -155,24 +160,31 @@ public class ExtendDataOperationTests extends RefineTest {
     public void SetUp() throws IOException, ModelException {
         OperationRegistry.registerOperation(getCoreModule(), "extend-reconciled-data", ExtendDataOperation.class);
         project = createProjectWithColumns("DataExtensionTests", "country");
+        project.columnModel.getColumnByName("country").setReconConfig(new DataExtensionReconConfig(RECON_SERVICE,
+                RECON_IDENTIFIER_SPACE,
+                RECON_SCHEMA_SPACE, null));
 
         options = mock(Properties.class);
         engine = new Engine(project);
-        engine_config = EngineConfig.reconstruct(ENGINE_JSON_URLS);
+        engine_config = EngineConfig.deserialize(ENGINE_JSON_URLS);
         engine.initializeFromConfig(engine_config);
         engine.setMode(Engine.Mode.RowBased);
 
         Row row = new Row(2);
-        row.setCell(0, reconciledCell("Iran", "Q794"));
+        reconCell1 = reconciledCell("Iran", "Q794");
+        row.setCell(0, reconCell1);
         project.rows.add(row);
         row = new Row(2);
-        row.setCell(0, reconciledCell("Japan", "Q17"));
+        reconCell2 = reconciledCell("Japan", "Q17");
+        row.setCell(0, reconCell2);
         project.rows.add(row);
         row = new Row(2);
-        row.setCell(0, reconciledCell("Tajikistan", "Q863"));
+        reconCell3 = reconciledCell("Tajikistan", "Q863");
+        row.setCell(0, reconCell3);
         project.rows.add(row);
         row = new Row(2);
-        row.setCell(0, reconciledCell("United States of America", "Q30"));
+        reconCell4 = reconciledCell("United States of America", "Q30");
+        row.setCell(0, reconCell4);
         project.rows.add(row);
 
         dispatcher = new Dispatcher() {
@@ -274,17 +286,68 @@ public class ExtendDataOperationTests extends RefineTest {
                     RECON_SCHEMA_SPACE,
                     extension,
                     1);
-            LongRunningProcessStub process = new LongRunningProcessStub(op.createProcess(project, options));
-            process.run();
 
-            // Inspect rows
-            Assert.assertTrue("IR".equals(project.rows.get(0).getCellValue(1)), "Bad country code for Iran.");
-            Assert.assertTrue("JP".equals(project.rows.get(1).getCellValue(1)), "Bad country code for Japan.");
-            Assert.assertNull(project.rows.get(2).getCell(1), "Expected a null country code.");
-            Assert.assertTrue("US".equals(project.rows.get(3).getCellValue(1)), "Bad country code for United States.");
+            runOperation(op, project);
+
+            Project expectedProject = createProject(
+                    new String[] { "country", "ISO 3166-1 alpha-2 code" },
+                    new Serializable[][] {
+                            { reconCell1, "IR" },
+                            { reconCell2, "JP" },
+                            { reconCell3, null },
+                            { reconCell4, "US" },
+                    });
+            assertProjectEquals(project, expectedProject);
 
             // Make sure we did not create any recon stats for that column (no reconciled value)
             Assert.assertTrue(project.columnModel.getColumnByName("ISO 3166-1 alpha-2 code").getReconStats() == null);
+            // adding an assertion for sourceReconConfig
+            Assert.assertTrue(project.columnModel.getColumnByName("ISO 3166-1 alpha-2 code").getSourceReconConfig() != null);
+
+        }
+    }
+
+    @Test
+    public void testFetchOtherDatatypes() throws Exception {
+
+        DataExtensionConfig extension = DataExtensionConfig
+                .reconstruct("{\"properties\":[{\"id\":\"P123\",\"name\":\"dummy property\"}]}");
+
+        try (MockWebServer server = new MockWebServer()) {
+            server.start();
+            server.setDispatcher(dispatcher);
+
+            mockHttpCall("{\"ids\":[\"Q863\",\"Q794\",\"Q17\",\"Q30\"],\"properties\":[{\"id\":\"P123\"}]}",
+                    "{"
+                            + "\"rows\": {"
+                            + "    \"Q794\": {\"P123\": [{\"int\": 4}]},"
+                            + "    \"Q863\": {\"P123\": []},"
+                            + "    \"Q30\": {\"P123\": [{\"date\": \"2023-05-03T04:05:06Z\"}]},"
+                            + "    \"Q17\": {\"P123\": [{\"bool\": true}]}"
+                            + "},"
+                            + "\"meta\": ["
+                            + "   {\"name\": \"dummy property\", \"id\": \"P123\"}"
+                            + "]}");
+
+            EngineDependentOperation op = new ExtendDataOperation(engine_config,
+                    "country",
+                    server.url("/reconcile").url().toString(),
+                    RECON_IDENTIFIER_SPACE,
+                    RECON_SCHEMA_SPACE,
+                    extension,
+                    1);
+
+            runOperation(op, project);
+
+            Project expectedProject = createProject(
+                    new String[] { "country", "dummy property" },
+                    new Serializable[][] {
+                            { reconCell1, 4 },
+                            { reconCell2, true },
+                            { reconCell3, null },
+                            { reconCell4, OffsetDateTime.parse("2023-05-03T04:05:06Z") },
+                    });
+            assertProjectEquals(project, expectedProject);
         }
     }
 
@@ -322,14 +385,17 @@ public class ExtendDataOperationTests extends RefineTest {
                     extension,
                     1);
 
-            LongRunningProcessStub process = new LongRunningProcessStub(op.createProcess(project, options));
-            process.run();
+            runOperation(op, project);
 
-            // Test to be updated as countries change currencies!
-            Assert.assertTrue(Math.round((double) project.rows.get(2).getCellValue(1)) == 2,
-                    "Incorrect number of currencies returned for Tajikistan.");
-            Assert.assertTrue(Math.round((double) project.rows.get(3).getCellValue(1)) == 1,
-                    "Incorrect number of currencies returned for United States.");
+            Project expectedProject = createProject(
+                    new String[] { "country", "currency" },
+                    new Serializable[][] {
+                            { reconCell1, 1.0 },
+                            { reconCell2, 1.0 },
+                            { reconCell3, 2.0 },
+                            { reconCell4, 1.0 },
+                    });
+            assertProjectEquals(project, expectedProject);
 
             // Make sure we did not create any recon stats for that column (no reconciled value)
             Assert.assertTrue(project.columnModel.getColumnByName("currency").getReconStats() == null);
@@ -366,8 +432,7 @@ public class ExtendDataOperationTests extends RefineTest {
                     extension,
                     1);
 
-            LongRunningProcessStub process = new LongRunningProcessStub(op.createProcess(project, options));
-            process.run();
+            runOperation(op, project);
 
             /*
              * Tajikistan has one "preferred" currency and one "normal" one (in terms of statement ranks). But thanks to
@@ -413,8 +478,7 @@ public class ExtendDataOperationTests extends RefineTest {
                     extension,
                     1);
 
-            LongRunningProcessStub process = new LongRunningProcessStub(op.createProcess(project, options));
-            process.run();
+            runOperation(op, project);
 
             /*
              * Tajikistan has one "preferred" currency and one "normal" one (in terms of statement ranks). The second
