@@ -87,7 +87,7 @@ class ScatterplotFacet extends Facet {
 
     this._div.empty().show().html(
       '<div class="facet-title">' +
-        '<div class="grid-layout layout-tightest layout-full"><table><tr>' +
+        '<div class="grid-layout layout-tightest layout-full"><table role="presentation"><tr>' +
           '<td width="1%">' +
             '<a href="javascript:{}" title="'+$.i18n('core-facets/remove-facet')+'" class="facet-title-remove" bind="removeButton">&nbsp;</a>' +
           '</td>' +
@@ -102,7 +102,7 @@ class ScatterplotFacet extends Facet {
       '</div>' +
       '<div class="facet-scatterplot-body" bind="bodyDiv">' +
         '<div class="facet-scatterplot-message" bind="messageDiv">'+$.i18n('core-facets/loading')+'</div>' +
-        '<table width="100%"><tr>' + 
+        '<table role="presentation" width="100%"><tr>' + 
           '<td>' +
             '<div class="facet-scatterplot-plot-container">' +
             '<div class="facet-scatterplot-plot" bind="plotDiv">' +
@@ -146,12 +146,14 @@ class ScatterplotFacet extends Facet {
     });
 
     this._elmts.plotDiv.width(this._config.l + "px").height(this._config.l + "px");
-    this._elmts.plotBaseImg.attr("src", this._formulateBaseImageUrl())
-    .attr("width", this._config.l)
-    .attr("height", this._config.l);
-    this._elmts.plotImg.attr("src", this._formulateCurrentImageUrl())
-    .attr("width", this._config.l)
-    .attr("height", this._config.l);
+    Refine.wrapCSRF(function(csrfToken) {
+      self._elmts.plotBaseImg.attr("src", self._formulateBaseImageUrl(csrfToken))
+        .attr("width", self._config.l)
+        .attr("height", self._config.l);
+      self._elmts.plotImg.attr("src", self._formulateCurrentImageUrl(csrfToken))
+        .attr("width", self._config.l)
+        .attr("height",self._config.l);
+    });
 
     var ops = {
         instance: true,        
@@ -252,19 +254,19 @@ class ScatterplotFacet extends Facet {
     }
   };
 
-  _formulateCurrentImageUrl() {
-    return this._formulateImageUrl(ui.browsingEngine.getJSON(false, this), { color: "ff6a00" });
+  _formulateCurrentImageUrl(csrfToken) {
+    return this._formulateImageUrl(ui.browsingEngine.getJSON(false, this), { color: "ff6a00" }, csrfToken);
   };
 
-  _formulateBaseImageUrl() {
-    return this._formulateImageUrl({},{ color: "888888", dot : this._config.dot * 0.9 });
+  _formulateBaseImageUrl(csrfToken) {
+    return this._formulateImageUrl({},{ color: "888888", dot : this._config.dot * 0.9 }, csrfToken);
   };
 
-  _formulateExportImageUrl() {
-    return this._formulateImageUrl(ui.browsingEngine.getJSON(false, this), { dot : this._config.dot * 5, l: 500, base_color: "888888" });
+  _formulateExportImageUrl(csrfToken) {
+    return this._formulateImageUrl(ui.browsingEngine.getJSON(false, this), { dot : this._config.dot * 5, l: 500, base_color: "888888" }, csrfToken);
   };
 
-  _formulateImageUrl(engineConfig, conf) {
+  _formulateImageUrl(engineConfig, conf, csrfToken) {
     var options = {};
     for (var p in this._config) {
       if (this._config.hasOwnProperty(p)) {        
@@ -279,11 +281,23 @@ class ScatterplotFacet extends Facet {
     var params = {
         project: theProject.id,
         engine: JSON.stringify(engineConfig), 
-        plotter: JSON.stringify(options) 
+        plotter: JSON.stringify(options),
+        csrf_token: csrfToken 
     };
     return "command/core/get-scatterplot?" + $.param(params);
   };
 
+  uniquenessCriterion() {
+    return JSON.stringify([
+      'scatterplot',
+      this._config.ex, // expression for X
+      this._config.cx, // columnName for X
+      this._config.ey, // expression for Y
+      this._config.cy, // column name for Y
+      this._config.r // rotation
+    ]);
+  }
+
   updateState(data) {
     if ("error" in data) {
       this._error = true;
@@ -326,9 +340,12 @@ class ScatterplotFacet extends Facet {
   };
 
   changePlot() {
-    this._elmts.plotBaseImg.attr("src", this._formulateBaseImageUrl());
-    this._elmts.plotImg.attr("src", this._formulateCurrentImageUrl());
-    this._elmts.exportPlotLink.attr("href", this._formulateExportImageUrl());
+    let self = this;
+    Refine.wrapCSRF(function(csrfToken) {
+      self._elmts.plotBaseImg.attr("src", self._formulateBaseImageUrl(csrfToken));
+      self._elmts.plotImg.attr("src", self._formulateCurrentImageUrl(csrfToken));
+      self._elmts.exportPlotLink.attr("href", self._formulateExportImageUrl(csrfToken));
+    });
   };
 
   render() {
@@ -348,8 +365,11 @@ class ScatterplotFacet extends Facet {
     this._elmts.plotDiv.show();
     this._elmts.statusDiv.show();
 
-    this._elmts.plotImg.attr("src", this._formulateCurrentImageUrl());
-    this._elmts.exportPlotLink.attr("href", this._formulateExportImageUrl());
+    let self = this;
+    Refine.wrapCSRF(function(csrfToken) {
+      self._elmts.plotImg.attr("src", self._formulateCurrentImageUrl(csrfToken));
+      self._elmts.exportPlotLink.attr("href", self._formulateExportImageUrl(csrfToken));
+    });
   };
 
   _updateRest() {
