@@ -47,11 +47,8 @@ Refine.SetLanguageUI = function(elmt) {
 	});
 };
 
-Refine.SetLanguageUI.prototype.resize = function() {
-};
-
 Refine.actionAreas.push({
-	id : "lang-settings",
+	id : "language-settings",
 	label : $.i18n('core-index-lang/lang-settings'),
 	uiClass : Refine.SetLanguageUI
 });
