@@ -67,6 +67,14 @@ Refine.LineBasedParserUI.prototype.getOptions = function() {
     recordPath: this._config.recordPath
   };
 
+  switch (this._optionContainer.find("input[name='row-separator']:checked")[0].value) {
+    case 'newline':
+      options.separator = "\\r?\\n";
+      break;
+    default:
+      options.separator = this._optionContainerElmts.rowSeparatorInput[0].value;
+  }
+
   var parseIntDefault = function(s, def) {
     try {
       var n = parseInt(s,10);
@@ -96,6 +104,7 @@ Refine.LineBasedParserUI.prototype.getOptions = function() {
     options.skipDataLines = -1;
   }
   options.storeBlankRows = this._optionContainerElmts.storeBlankRowsCheckbox[0].checked;
+  options.storeBlankColumns = this._optionContainerElmts.storeBlankColumnsCheckbox[0].checked;
   options.storeBlankCellsAsNulls = this._optionContainerElmts.storeBlankCellsAsNullsCheckbox[0].checked;
   options.includeFileSources = this._optionContainerElmts.includeFileSourcesCheckbox[0].checked;
   options.includeArchiveFileName = this._optionContainerElmts.includeArchiveFileCheckbox[0].checked;
@@ -119,6 +128,7 @@ Refine.LineBasedParserUI.prototype._initialize = function() {
   $('#or-import-parseEvery').html($.i18n('core-index-parser/parse-every'));
   $('#or-import-linesIntoRow').html($.i18n('core-index-parser/lines-into-row'));
   $('#or-import-blank').text($.i18n('core-index-parser/store-blank'));
+  $('#or-import-blank-columns').text($.i18n('core-index-parser/store-blank-columns'));
   $('#or-import-null').text($.i18n('core-index-parser/store-nulls'));
   $('#or-import-source').html($.i18n('core-index-parser/store-source'));
   $('#or-import-archive').html($.i18n('core-index-parser/store-archive'));
@@ -130,7 +140,10 @@ Refine.LineBasedParserUI.prototype._initialize = function() {
   $('#or-import-rows').text($.i18n('core-index-parser/rows-data'));
   $('#or-import-load').text($.i18n('core-index-parser/load-at-most'));
   $('#or-import-rows2').text($.i18n('core-index-parser/rows-data'));
-  
+  $('#or-row-separator').text($.i18n('core-index-parser/row-separator'));
+  $('#or-row-separator-newline').text($.i18n('core-index-parser/row-separator-newline'));
+  $('#or-row-separator-regex').text($.i18n('core-index-parser/row-separator-regex'));
+
   this._optionContainerElmts.encodingInput
     .val(this._config.encoding || '')
     .on('click',function() {
@@ -139,6 +152,12 @@ Refine.LineBasedParserUI.prototype._initialize = function() {
       });
     });
 
+
+  var rowSeparatorValue = (this._config.separator == "\\r?\\n") ? 'newline' : 'custom';
+  this._optionContainer.find(
+      "input[name='row-separator'][value='" + rowSeparatorValue + "']").prop("checked", true);
+  this._optionContainerElmts.rowSeparatorInput[0].value = this._config.separator;
+
   this._optionContainerElmts.linesPerRowInput[0].value =
     this._config.linesPerRow.toString();
 
@@ -157,6 +176,9 @@ Refine.LineBasedParserUI.prototype._initialize = function() {
   if (this._config.storeBlankRows) {
     this._optionContainerElmts.storeBlankRowsCheckbox.prop("checked", true);
   }
+  if (this._config.storeBlankColumns) {
+    this._optionContainerElmts.storeBlankColumnsCheckbox.prop("checked", true);
+  }
   if (this._config.storeBlankCellsAsNulls) {
     this._optionContainerElmts.storeBlankCellsAsNullsCheckbox.prop("checked", true);
   }
