@@ -92,6 +92,7 @@ Refine.WikitextParserUI.prototype.getOptions = function() {
   }
 
   options.storeBlankRows = this._optionContainerElmts.storeBlankRowsCheckbox[0].checked;
+  options.storeBlankColumns = this._optionContainerElmts.storeBlankColumnsCheckbox[0].checked;
   options.blankSpanningCells = this._optionContainerElmts.blankSpanningCellsCheckbox[0].checked;
   options.includeRawTemplates = this._optionContainerElmts.includeRawTemplatesCheckbox[0].checked;
   options.parseReferences = this._optionContainerElmts.parseReferencesCheckbox[0].checked;
@@ -129,6 +130,7 @@ Refine.WikitextParserUI.prototype._initialize = function() {
   $('#or-import-includeRawTemplates').text($.i18n('core-index-parser/include-raw-templates'));
   $('#or-import-parseReferences').text($.i18n('core-index-parser/parse-references'));
   $('#or-import-blank').text($.i18n('core-index-parser/store-blank'));
+  $('#or-import-blank-columns').text($.i18n('core-index-parser/store-blank-columns'));
   $('#or-import-null').text($.i18n('core-index-parser/store-nulls'));
   $('#or-import-source').html($.i18n('core-index-parser/store-source'));
   $('#or-import-archive').html($.i18n('core-index-parser/store-archive'));
@@ -176,6 +178,10 @@ Refine.WikitextParserUI.prototype._initialize = function() {
     this._optionContainerElmts.storeBlankRowsCheckbox.prop("checked", true);
   }
 
+  if (this._config.storeBlankColumns) {
+    this._optionContainerElmts.storeBlankColumnsCheckbox.prop("checked", true);
+  }
+
   if (this._config.guessCellValueTypes) {
     this._optionContainerElmts.guessCellValueTypesCheckbox.prop("checked", true);
   }
