@@ -110,8 +110,6 @@ function resizeAll() {
 function initializeUI(uiState) {
   $("#loading-message").hide();
   $("#notification-container").hide();
-  $("#project-title").show();
-  $("#project-controls").show();
   $("#body").show();
 
   $("#or-proj-open").text($.i18n('core-project/open')+"...");
@@ -125,10 +123,12 @@ function initializeUI(uiState) {
   $("#or-proj-ext").text($.i18n('core-project/extensions'));
 
   $('#project-name-button').on('click',Refine._renameProject);
-  $('#project-permalink-button').on('mouseenter',function() {
+  $('#project-permalink-button').on('focus',function() {
     this.href = Refine.getPermanentLink();
   });
 
+  $('#app-home-button').attr('title', $.i18n('core-index/navigate-home'));
+
   Refine.setTitle();
 
   ui = DOM.bind($("#body"));
@@ -140,13 +140,15 @@ function initializeUI(uiState) {
   resize();
   resizeTabs();
 
-  $('<a>').attr("id", "hide-left-panel-button")
+  $('<button>').attr("id", "hide-left-panel-button")
     .addClass("visibility-panel-button")
+    .attr("aria-label", $.i18n('core-index/hide-panel'))
     .on('click',function() { Refine._showHideLeftPanel(); })
     .prependTo(ui.leftPanelTabs);
 
-  $('<a>').attr("id", "show-left-panel-button")
+  $('<button>').attr("id", "show-left-panel-button")
     .addClass("visibility-panel-button")
+    .attr("aria-label", $.i18n('core-index/show-panel'))
     .on('click',function() { Refine._showHideLeftPanel(); })
     .prependTo(ui.toolPanelDiv);
 
@@ -189,55 +191,45 @@ Refine.setTitle = function(status) {
 };
 
 Refine.reinitializeProjectData = function(f, fError) {
-  $.getJSON(
-    "command/core/get-project-metadata?" + $.param({ project: theProject.id }), null,
-    function(data) {
-      if (data.status == "error") {
-        alert(data.message);
-        if (fError) {
-          fError();
-        }
-      } else {
-        theProject.metadata = data;
-        $.getJSON(
-          "command/core/get-models?" + $.param({ project: theProject.id }), null,
-          function(data) {
-            if (data.status == "error") {
-              alert(data.message);
-              if (fError) {
-                fError();
-              }
-            } else {
-              for (var n in data) {
-                if (data.hasOwnProperty(n)) {
-                  theProject[n] = data[n];
-                }
-              }
-              $.post(
-                "command/core/get-all-preferences", null,
-                function(preferences) {
-                  if (preferences.status == "error") {
-                    alert(preferences.message);
-                    if (fError) {
-                      fError();
-                    }
-                  } else {
-                    if (preferences != null) {
-                      thePreferences = preferences;
-                    }
-                    f();
-                  }
-                },
-                'json'
-              );
-            }
-          },
-          'json'
-        );
+  function handleError(status, message, fError) {
+    if (status === "error") {
+      alert(message);
+      if (fError) {
+        fError();
       }
-    },
-    'json'
-  );
+      return true;
+    }
+    return false;
+  }
+
+  $.when(
+    $.getJSON("command/core/get-project-metadata?" + $.param({ project: theProject.id }), null),
+    $.getJSON("command/core/get-models?" + $.param({ project: theProject.id }), null),
+    $.getJSON("command/core/get-all-preferences", null),
+  ).done(function(metadata, models, preferences) {
+    metadata = metadata[0], models = models[0], preferences = preferences[0];
+    if (
+      handleError(metadata.status, metadata.message, fError) ||
+      handleError(models.status, models.message, fError) ||
+      handleError(preferences.status, preferences.message, fError)
+    ) {
+      return;
+    }
+
+    theProject.metadata = metadata;
+
+    for (var n in models) {
+      if (models.hasOwnProperty(n)) {
+        theProject[n] = models[n];
+      }
+    }
+
+    if (preferences) {
+      thePreferences = preferences;
+    }
+
+    f();
+  });
 };
 
 Refine.getPreference = function(key, defaultValue) {
@@ -312,8 +304,9 @@ Refine.createUpdateFunction = function(options, onFinallyDone) {
     pushFunction(Refine.reinitializeProjectData);
   }
   if (options.everythingChanged || options.modelsChanged || options.rowsChanged || options.rowMetadataChanged || options.cellsChanged || options.engineChanged) {
+    var preservePage = options.rowIdsPreserved && (options.recordIdsPreserved || ui.browsingEngine.getMode() === "row-based");
     pushFunction(function(onDone) {
-      ui.dataTableView.update(onDone);
+      ui.dataTableView.update(onDone, preservePage);
     });
     pushFunction(function(onDone) {
       ui.browsingEngine.update(onDone);
@@ -444,20 +437,29 @@ Refine.postProcess = function(moduleName, command, params, body, updateOptions,
     }
   }
 
-  Refine.setAjaxInProgress();
+  var runChange = function() {
+    Refine.setAjaxInProgress();
 
-  Refine.postCSRF(
-    "command/" + moduleName + "/" + command + "?" + $.param(params),
-    body,
-    onDone,
-    "json"
-  );
+    Refine.postCSRF(
+        "command/" + moduleName + "/" + command + "?" + $.param(params),
+        body,
+        onDone,
+        "json"
+    );
 
-  window.setTimeout(function() {
-    if (!done) {
-      dismissBusy = DialogSystem.showBusy();
-    }
-  }, 500);
+    window.setTimeout(function() {
+      if (!done) {
+        dismissBusy = DialogSystem.showBusy();
+      }
+    }, 500);
+  }
+
+  var undoneChanges = ui.historyPanel.undoneChanges();
+  if (Refine.getPreference("ui.history.warnAgainstDeletion", 'true') === 'true' && undoneChanges.length > 0 && (!("warnAgainstHistoryErasure" in updateOptions) || updateOptions.warnAgainstHistoryErasure)) {
+    Refine._confirmHistoryErasure(undoneChanges, runChange);
+  } else {
+    runChange();
+  }
 };
 
 Refine.setAjaxInProgress = function() {
@@ -468,6 +470,46 @@ Refine.clearAjaxInProgress = function() {
   $(document.body).attr("ajax_in_progress", "false");
 };
 
+/**
+ * Confirmation of erasure of history, when applying an operation with changes undone
+ */
+Refine._confirmHistoryErasure = function(entries, onDone) {
+  var self = this;
+  var frame = $(DOM.loadHTML("core", "scripts/util/confirm-history-erasure-dialog.html"));
+  var elmts = DOM.bind(frame);
+  var level = DialogSystem.showDialog(frame);
+  
+  elmts.dialogHeader.text($.i18n('core-project/confirm-erasure-of-project-history'));
+  elmts.warningText.text($.i18n('core-project/applying-change-erases-entries', entries.length));
+  elmts.doNotWarnText.text($.i18n('core-project/do-not-warn'));
+  elmts.cancelButton.text($.i18n('core-buttons/cancel'));
+  elmts.okButton.text($.i18n('core-buttons/apply-anyway'));
+
+  // populate the history entries
+  for (let entry of entries) {
+    var entryDom = $(DOM.loadHTML("core", "scripts/project/history-entry.html")).appendTo(elmts.entryList);
+    var entryElmts = DOM.bind(entryDom);
+    entryElmts.entryDescription.text(entry.description);
+  }
+
+  var updateWarnPreferences = function () {
+    var doNotWarnCheckBox = elmts.doNotWarnCheckbox.is(':checked');
+    if (doNotWarnCheckBox) {
+      Refine.setPreference('ui.history.warnAgainstDeletion', 'false');
+    }
+  };
+  
+  elmts.form.on('submit', function() {
+    DialogSystem.dismissUntil(level - 1);
+    updateWarnPreferences();
+    onDone();
+  });
+  elmts.cancelButton.on('click',function() {
+    updateWarnPreferences();
+    DialogSystem.dismissUntil(level - 1);
+  });
+};
+
 /*
  *  Utility model functions
  */
@@ -503,7 +545,11 @@ Refine.columnNameToColumnIndex = function(columnName) {
   return -1;
 };
 
-Refine.fetchRows = function(start, limit, onDone, sorting) {
+/*
+  Fetch rows after or before a given row id. The engine configuration can also
+  be used to set filters (facets) or switch between rows/records mode.
+*/
+Refine.fetchRows = function(paginationOptions, limit, onDone, sorting) {
   var body = {
     engine: JSON.stringify(ui.browsingEngine.getJSON())
   };
@@ -512,7 +558,7 @@ Refine.fetchRows = function(start, limit, onDone, sorting) {
   }
 
   $.post(
-    "command/core/get-rows?" + $.param({ project: theProject.id, start: start, limit: limit }),
+    "command/core/get-rows?" + $.param({ ...paginationOptions, project: theProject.id, limit: limit }),
     body,
     function(data) {
       if(data.code === "error") {
@@ -554,7 +600,7 @@ Refine.getPermanentLink = function() {
  */
 
 function onLoad() {
-  var params = URL.getParameters();
+  var params = URLUtil.getParameters();
   if ("project" in params) {
     var uiState = {};
     if ("ui" in params) {
