@@ -63,6 +63,7 @@ function BrowsingEngine(div, facetConfigs) {
       }
 
       this._facets.push({ elmt: elmt, facet: facet });
+      facet.prepareUI();
     }
   }
 }
@@ -168,7 +169,7 @@ BrowsingEngine.prototype.getJSON = function(keepUnrestrictedFacets, except) {
   return a;
 };
 
-BrowsingEngine.prototype.addFacet = function(type, config, options) {
+BrowsingEngine.prototype.addFacet = function(type, config, options, avoidDuplicates) {
   var elmt = this._createFacetContainer();
   var facet;
   switch (type) {
@@ -188,9 +189,30 @@ BrowsingEngine.prototype.addFacet = function(type, config, options) {
     facet = new ListFacet(elmt, config, options);
   }
 
+  if (avoidDuplicates) {
+    let criterion = facet.uniquenessCriterion();
+    if (this._facets.findIndex(existingFacet => existingFacet.facet.uniquenessCriterion() == criterion) != -1) {
+      // skip addition of the facet because it already exists
+      return;
+    }
+  }
+
   this._facets.push({ elmt: elmt, facet: facet });
+  facet.prepareUI();
 
   ui.leftPanelTabs.tabs();
+  ui.leftPanelTabs.on( "tabsactivate", ( event, ui ) =>  {
+     let activeTabId = ui.newTab.children('a').attr("href");
+     if (activeTabId === '#refine-tabs-facets') {
+       for (let facet of this._facets) {
+         if (facet.facet.render) {
+           facet.facet.render();
+         } else if (facet.facet.checkInitialHeight) {
+           facet.facet.checkInitialHeight();
+         }
+       }
+     }
+  });
 
   Refine.update({ engineChanged: true });
 };
@@ -240,10 +262,10 @@ BrowsingEngine.prototype.update = function(onDone) {
   this._elmts.help.hide();
 
   this._elmts.header.show();
-  this._elmts.controls.css("visibility", "hidden");
+  this._elmts.controls.css("display", "none");
   this._elmts.indicator.css("display", "block");
 
-  $.post(
+  Refine.postCSRF(
     "command/core/compute-facets?" + $.param({ project: theProject.id }),
     { engine: JSON.stringify(this.getJSON(true)) },
     function(data) {
@@ -261,14 +283,15 @@ BrowsingEngine.prototype.update = function(onDone) {
       var facetData = data.facets;
 
       for (var i = 0; i < facetData.length; i++) {
-        self._facets[i].facet.updateState(facetData[i]);
+        const column = theProject.columnModel.columns.find(col => col.name === facetData[i].columnName);
+        self._facets[i].facet.updateState(facetData[i], column);
       }
 
       self._elmts.indicator.css("display", "none");
       self._elmts.errors.css("display", "none");
       if (self._facets.length > 0) {
         self._elmts.header.show();
-        self._elmts.controls.css("visibility", "visible");
+        self._elmts.controls.css("display", "block");
 
         self.resize();
       } else {
