@@ -70,7 +70,7 @@ ExtensionBar.prototype._initializeUI = function() {
 ExtensionBar.prototype._createMenuButton = function(label, submenu) {
   var self = this;
 
-  var menuItem = $("<a>").addClass("button").append('<span class="button-menu">' + label + '</span>');
+  var menuItem = $("<button>").append('<span class="button-menu">' + label + '</span>');
 
   menuItem.on('click',function(evt) {
     MenuSystem.createAndShowStandardMenu(
