@@ -44,29 +44,30 @@ import java.net.URI;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
+import java.util.Set;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 
 import javax.swing.JFrame;
 
-import org.apache.commons.lang.SystemUtils;
-import org.apache.log4j.Level;
+import com.google.util.threads.ThreadPoolExecutorAdapter;
+import org.apache.commons.lang3.SystemUtils;
+import org.apache.logging.log4j.Level;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.core.config.Configurator;
 import org.eclipse.jetty.server.HttpConfiguration;
 import org.eclipse.jetty.server.HttpConnectionFactory;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.server.ServerConnector;
 import org.eclipse.jetty.server.handler.StatisticsHandler;
 import org.eclipse.jetty.servlet.ServletHolder;
-import org.eclipse.jetty.webapp.WebAppContext;
 import org.eclipse.jetty.util.Scanner;
 import org.eclipse.jetty.util.thread.ThreadPool;
-import com.google.util.threads.ThreadPoolExecutorAdapter;
+import org.eclipse.jetty.webapp.WebAppContext;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.refine.Configurations;
-
 /**
  * Main class for Refine server application. Starts an instance of the Jetty HTTP server / servlet container (inner
  * class Refine Server).
@@ -97,7 +98,10 @@ public class Refine {
         // System.setProperty("debug","true");
 
         // set the log verbosity level
-        org.apache.log4j.Logger.getRootLogger().setLevel(Level.toLevel(Configurations.get("refine.verbosity", "info")));
+        String logLevelArg = Configurations.get("refine.verbosity");
+        if (logLevelArg != null && !logLevelArg.isEmpty()) {
+            Configurator.setAllLevels(LogManager.getRootLogger().getName(), Level.toLevel(logLevelArg));
+        }
 
         port = Configurations.getInteger("refine.port", DEFAULT_PORT);
         iface = Configurations.get("refine.interface", DEFAULT_IFACE);
@@ -116,6 +120,7 @@ public class Refine {
 
         RefineServer server = new RefineServer();
         server.init(iface, port, host);
+        String contextPath = server.getURI().getPath();
 
         boolean headless = Configurations.getBoolean("refine.headless", false);
         if (headless) {
@@ -127,12 +132,12 @@ public class Refine {
                 if ("*".equals(host)) {
                     if ("0.0.0.0".equals(iface)) {
                         logger.warn("No refine.host specified while binding to interface 0.0.0.0, guessing localhost.");
-                        client.init("localhost", port);
+                        client.init("localhost", port, contextPath);
                     } else {
-                        client.init(iface, port);
+                        client.init(iface, port, contextPath);
                     }
                 } else {
-                    client.init(host, port);
+                    client.init(host, port, contextPath);
                 }
             } catch (Exception e) {
                 logger.warn("Sorry, some error prevented us from launching the browser for you.\n\n Point your browser to http://" + host
@@ -169,12 +174,12 @@ class RefineServer extends Server {
     private ThreadPoolExecutor threadPool;
 
     public void init(String iface, int port, String host) throws Exception {
-        logger.info("Starting Server bound to '" + iface + ":" + port + "'");
-
-        String memory = Configurations.get("refine.memory");
-        if (memory != null) {
-            logger.info("refine.memory size: " + memory + " JVM Max heap: " + Runtime.getRuntime().maxMemory());
-        }
+        logger.info("Java runtime version {} from java.home: {}", Runtime.version().toString(), System.getProperty("java.home", ""));
+        logger.info("Java VM: {} {} {} {}", System.getProperty("java.vm.vendor", ""), System.getProperty("java.vm.name", ""),
+                System.getProperty("java.vm.version", ""), System.getProperty("java.vm.info", ""));
+        logger.info("Starting Server bound to http://{}:{}", iface, port);
+        logger.info("refine.memory size: {} JVM Max heap: {} MBytes", Configurations.get("refine.memory", "<default>"),
+                Runtime.getRuntime().maxMemory() / 1024 / 1024.0);
 
         HttpConfiguration httpConfig = new HttpConfiguration();
         httpConfig.setSendServerVersion(false);
@@ -220,7 +225,7 @@ class RefineServer extends Server {
         this.addBean(handler);
         // Tell the server we want to try and shutdown gracefully
         // this means that the server will stop accepting new connections
-        // right away but it will continue to process the ones that
+        // right away, but it will continue to process the ones that
         // are in execution for the given timeout before attempting to stop
         // NOTE: this is *not* a blocking method, it just sets a parameter
         // that _server.stop() will rely on
@@ -286,7 +291,7 @@ class RefineServer extends Server {
         scanner.addListener(new Scanner.BulkListener() {
 
             @Override
-            public void filesChanged(@SuppressWarnings("rawtypes") List changedFiles) {
+            public void filesChanged(Set<String> set) {
                 try {
                     logger.info("Stopping context: " + contextRoot.getAbsolutePath());
                     context.stop();
@@ -337,14 +342,6 @@ class RefineServer extends Server {
             servlet.setInitOrder(1);
             servlet.doStart();
         }
-
-        servlet = context.getServletHandler().getServlet("refine-broker");
-        if (servlet != null) {
-            servlet.setInitParameter("refine.data", getDataDir() + "/broker");
-            servlet.setInitParameter("refine.development", Configurations.get("refine.development", "false"));
-            servlet.setInitOrder(1);
-            servlet.doStart();
-        }
     }
 
     static private String getDataDir() {
@@ -354,6 +351,7 @@ class RefineServer extends Server {
         }
 
         File dataDir = null;
+        File extensionsDir = null;
         File grefineDir = null;
         File gridworksDir = null;
 
@@ -378,6 +376,7 @@ class RefineServer extends Server {
             }
 
             dataDir = new File(parentDir, "OpenRefine");
+            extensionsDir = new File(dataDir, "extensions");
             grefineDir = new File(new File(parentDir, "Google"), "Refine");
             gridworksDir = new File(parentDir, "Gridworks");
         } else if (os.contains("os x")) {
@@ -392,6 +391,10 @@ class RefineServer extends Server {
 
             String gridworks_home = (home != null) ? home + "/Library/Application Support/Gridworks" : ".gridworks";
             gridworksDir = new File(gridworks_home);
+
+            String extensions_home = (home != null) ? home + "/Library/Application Support/OpenRefine/extensions"
+                    : ".openrefine/extensions";
+            extensionsDir = new File(extensions_home);
         } else { // most likely a UNIX flavor
             // start with the XDG environment
             // see http://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html
@@ -405,6 +408,7 @@ class RefineServer extends Server {
             }
 
             dataDir = new File(data_home + "/openrefine");
+            extensionsDir = new File(data_home + "/openrefine/extensions");
             grefineDir = new File(data_home + "/google/refine");
             gridworksDir = new File(data_home + "/gridworks");
         }
@@ -444,6 +448,12 @@ class RefineServer extends Server {
             }
         }
 
+        if (!extensionsDir.exists()) {
+            if (!extensionsDir.mkdirs()) {
+                logger.error("FAILED to create new extensions directory " + extensionsDir);
+            }
+        }
+
         return dataDir.getAbsolutePath();
     }
 
@@ -483,8 +493,8 @@ class RefineClient extends JFrame implements ActionListener {
 
     private URI uri;
 
-    public void init(String host, int port) throws Exception {
-        uri = new URI("http://" + host + ":" + port + "/");
+    public void init(String host, int port, String contextPath) throws Exception {
+        uri = new URI("http://" + host + ":" + port + contextPath);
         openBrowser();
     }
 
@@ -516,13 +526,13 @@ class RefineClient extends JFrame implements ActionListener {
         Runtime rt = Runtime.getRuntime();
 
         if (SystemUtils.IS_OS_WINDOWS) {
-            rt.exec("rundll32 url.dll,FileProtocolHandler " + uri);
+            rt.exec(new String[] { "rundll32 ", "url.dll,FileProtocolHandler ", String.valueOf(uri) });
         } else if (SystemUtils.IS_OS_MAC_OSX) {
-            rt.exec("open " + uri);
+            rt.exec(new String[] { "open ", String.valueOf(uri) });
         } else if (SystemUtils.IS_OS_LINUX) {
-            rt.exec("xdg-open " + uri);
+            rt.exec(new String[] { "xdg-open", String.valueOf(uri) });
         } else {
-            logger.warn("Java Desktop class not supported on this platform. Please open %s in your browser", uri.toString());
+            logger.warn("Java Desktop class not supported on this platform. Please open {} in your browser", uri.toString());
         }
     }
 }
